#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AddressInfo import AddressInfo
from alipay.aop.api.domain.BankCardInfo import BankCardInfo
from alipay.aop.api.domain.ContactInfo import ContactInfo
from alipay.aop.api.domain.SiteInfo import SiteInfo


class AntMerchantExpandIndirectModifyModel(object):

    def __init__(self):
        self._address_info = None
        self._alias_name = None
        self._bankcard_info = None
        self._business_license = None
        self._business_license_type = None
        self._category_id = None
        self._contact_info = None
        self._external_id = None
        self._logon_id = None
        self._mcc = None
        self._memo = None
        self._name = None
        self._org_pid = None
        self._pay_code_info = None
        self._service_codes = None
        self._service_phone = None
        self._site_info = None
        self._source = None
        self._sub_merchant_id = None

    @property
    def address_info(self):
        return self._address_info

    @address_info.setter
    def address_info(self, value):
        if isinstance(value, list):
            self._address_info = list()
            for i in value:
                if isinstance(i, AddressInfo):
                    self._address_info.append(i)
                else:
                    self._address_info.append(AddressInfo.from_alipay_dict(i))
    @property
    def alias_name(self):
        return self._alias_name

    @alias_name.setter
    def alias_name(self, value):
        self._alias_name = value
    @property
    def bankcard_info(self):
        return self._bankcard_info

    @bankcard_info.setter
    def bankcard_info(self, value):
        if isinstance(value, list):
            self._bankcard_info = list()
            for i in value:
                if isinstance(i, BankCardInfo):
                    self._bankcard_info.append(i)
                else:
                    self._bankcard_info.append(BankCardInfo.from_alipay_dict(i))
    @property
    def business_license(self):
        return self._business_license

    @business_license.setter
    def business_license(self, value):
        self._business_license = value
    @property
    def business_license_type(self):
        return self._business_license_type

    @business_license_type.setter
    def business_license_type(self, value):
        self._business_license_type = value
    @property
    def category_id(self):
        return self._category_id

    @category_id.setter
    def category_id(self, value):
        self._category_id = value
    @property
    def contact_info(self):
        return self._contact_info

    @contact_info.setter
    def contact_info(self, value):
        if isinstance(value, list):
            self._contact_info = list()
            for i in value:
                if isinstance(i, ContactInfo):
                    self._contact_info.append(i)
                else:
                    self._contact_info.append(ContactInfo.from_alipay_dict(i))
    @property
    def external_id(self):
        return self._external_id

    @external_id.setter
    def external_id(self, value):
        self._external_id = value
    @property
    def logon_id(self):
        return self._logon_id

    @logon_id.setter
    def logon_id(self, value):
        if isinstance(value, list):
            self._logon_id = list()
            for i in value:
                self._logon_id.append(i)
    @property
    def mcc(self):
        return self._mcc

    @mcc.setter
    def mcc(self, value):
        self._mcc = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def org_pid(self):
        return self._org_pid

    @org_pid.setter
    def org_pid(self, value):
        self._org_pid = value
    @property
    def pay_code_info(self):
        return self._pay_code_info

    @pay_code_info.setter
    def pay_code_info(self, value):
        if isinstance(value, list):
            self._pay_code_info = list()
            for i in value:
                self._pay_code_info.append(i)
    @property
    def service_codes(self):
        return self._service_codes

    @service_codes.setter
    def service_codes(self, value):
        if isinstance(value, list):
            self._service_codes = list()
            for i in value:
                self._service_codes.append(i)
    @property
    def service_phone(self):
        return self._service_phone

    @service_phone.setter
    def service_phone(self, value):
        self._service_phone = value
    @property
    def site_info(self):
        return self._site_info

    @site_info.setter
    def site_info(self, value):
        if isinstance(value, list):
            self._site_info = list()
            for i in value:
                if isinstance(i, SiteInfo):
                    self._site_info.append(i)
                else:
                    self._site_info.append(SiteInfo.from_alipay_dict(i))
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def sub_merchant_id(self):
        return self._sub_merchant_id

    @sub_merchant_id.setter
    def sub_merchant_id(self, value):
        self._sub_merchant_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.address_info:
            if isinstance(self.address_info, list):
                for i in range(0, len(self.address_info)):
                    element = self.address_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.address_info[i] = element.to_alipay_dict()
            if hasattr(self.address_info, 'to_alipay_dict'):
                params['address_info'] = self.address_info.to_alipay_dict()
            else:
                params['address_info'] = self.address_info
        if self.alias_name:
            if hasattr(self.alias_name, 'to_alipay_dict'):
                params['alias_name'] = self.alias_name.to_alipay_dict()
            else:
                params['alias_name'] = self.alias_name
        if self.bankcard_info:
            if isinstance(self.bankcard_info, list):
                for i in range(0, len(self.bankcard_info)):
                    element = self.bankcard_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.bankcard_info[i] = element.to_alipay_dict()
            if hasattr(self.bankcard_info, 'to_alipay_dict'):
                params['bankcard_info'] = self.bankcard_info.to_alipay_dict()
            else:
                params['bankcard_info'] = self.bankcard_info
        if self.business_license:
            if hasattr(self.business_license, 'to_alipay_dict'):
                params['business_license'] = self.business_license.to_alipay_dict()
            else:
                params['business_license'] = self.business_license
        if self.business_license_type:
            if hasattr(self.business_license_type, 'to_alipay_dict'):
                params['business_license_type'] = self.business_license_type.to_alipay_dict()
            else:
                params['business_license_type'] = self.business_license_type
        if self.category_id:
            if hasattr(self.category_id, 'to_alipay_dict'):
                params['category_id'] = self.category_id.to_alipay_dict()
            else:
                params['category_id'] = self.category_id
        if self.contact_info:
            if isinstance(self.contact_info, list):
                for i in range(0, len(self.contact_info)):
                    element = self.contact_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.contact_info[i] = element.to_alipay_dict()
            if hasattr(self.contact_info, 'to_alipay_dict'):
                params['contact_info'] = self.contact_info.to_alipay_dict()
            else:
                params['contact_info'] = self.contact_info
        if self.external_id:
            if hasattr(self.external_id, 'to_alipay_dict'):
                params['external_id'] = self.external_id.to_alipay_dict()
            else:
                params['external_id'] = self.external_id
        if self.logon_id:
            if isinstance(self.logon_id, list):
                for i in range(0, len(self.logon_id)):
                    element = self.logon_id[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.logon_id[i] = element.to_alipay_dict()
            if hasattr(self.logon_id, 'to_alipay_dict'):
                params['logon_id'] = self.logon_id.to_alipay_dict()
            else:
                params['logon_id'] = self.logon_id
        if self.mcc:
            if hasattr(self.mcc, 'to_alipay_dict'):
                params['mcc'] = self.mcc.to_alipay_dict()
            else:
                params['mcc'] = self.mcc
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.org_pid:
            if hasattr(self.org_pid, 'to_alipay_dict'):
                params['org_pid'] = self.org_pid.to_alipay_dict()
            else:
                params['org_pid'] = self.org_pid
        if self.pay_code_info:
            if isinstance(self.pay_code_info, list):
                for i in range(0, len(self.pay_code_info)):
                    element = self.pay_code_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.pay_code_info[i] = element.to_alipay_dict()
            if hasattr(self.pay_code_info, 'to_alipay_dict'):
                params['pay_code_info'] = self.pay_code_info.to_alipay_dict()
            else:
                params['pay_code_info'] = self.pay_code_info
        if self.service_codes:
            if isinstance(self.service_codes, list):
                for i in range(0, len(self.service_codes)):
                    element = self.service_codes[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.service_codes[i] = element.to_alipay_dict()
            if hasattr(self.service_codes, 'to_alipay_dict'):
                params['service_codes'] = self.service_codes.to_alipay_dict()
            else:
                params['service_codes'] = self.service_codes
        if self.service_phone:
            if hasattr(self.service_phone, 'to_alipay_dict'):
                params['service_phone'] = self.service_phone.to_alipay_dict()
            else:
                params['service_phone'] = self.service_phone
        if self.site_info:
            if isinstance(self.site_info, list):
                for i in range(0, len(self.site_info)):
                    element = self.site_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.site_info[i] = element.to_alipay_dict()
            if hasattr(self.site_info, 'to_alipay_dict'):
                params['site_info'] = self.site_info.to_alipay_dict()
            else:
                params['site_info'] = self.site_info
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.sub_merchant_id:
            if hasattr(self.sub_merchant_id, 'to_alipay_dict'):
                params['sub_merchant_id'] = self.sub_merchant_id.to_alipay_dict()
            else:
                params['sub_merchant_id'] = self.sub_merchant_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandIndirectModifyModel()
        if 'address_info' in d:
            o.address_info = d['address_info']
        if 'alias_name' in d:
            o.alias_name = d['alias_name']
        if 'bankcard_info' in d:
            o.bankcard_info = d['bankcard_info']
        if 'business_license' in d:
            o.business_license = d['business_license']
        if 'business_license_type' in d:
            o.business_license_type = d['business_license_type']
        if 'category_id' in d:
            o.category_id = d['category_id']
        if 'contact_info' in d:
            o.contact_info = d['contact_info']
        if 'external_id' in d:
            o.external_id = d['external_id']
        if 'logon_id' in d:
            o.logon_id = d['logon_id']
        if 'mcc' in d:
            o.mcc = d['mcc']
        if 'memo' in d:
            o.memo = d['memo']
        if 'name' in d:
            o.name = d['name']
        if 'org_pid' in d:
            o.org_pid = d['org_pid']
        if 'pay_code_info' in d:
            o.pay_code_info = d['pay_code_info']
        if 'service_codes' in d:
            o.service_codes = d['service_codes']
        if 'service_phone' in d:
            o.service_phone = d['service_phone']
        if 'site_info' in d:
            o.site_info = d['site_info']
        if 'source' in d:
            o.source = d['source']
        if 'sub_merchant_id' in d:
            o.sub_merchant_id = d['sub_merchant_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.EduRefundInfo import EduRefundInfo


class AlipayCommerceEducateBillServiceModifyModel(object):

    def __init__(self):
        self._isv_order_no = None
        self._open_id = None
        self._order_status = None
        self._refund_info = None
        self._source = None
        self._trade_no = None
        self._user_id = None

    @property
    def isv_order_no(self):
        return self._isv_order_no

    @isv_order_no.setter
    def isv_order_no(self, value):
        self._isv_order_no = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value
    @property
    def refund_info(self):
        return self._refund_info

    @refund_info.setter
    def refund_info(self, value):
        if isinstance(value, EduRefundInfo):
            self._refund_info = value
        else:
            self._refund_info = EduRefundInfo.from_alipay_dict(value)
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.isv_order_no:
            if hasattr(self.isv_order_no, 'to_alipay_dict'):
                params['isv_order_no'] = self.isv_order_no.to_alipay_dict()
            else:
                params['isv_order_no'] = self.isv_order_no
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.order_status:
            if hasattr(self.order_status, 'to_alipay_dict'):
                params['order_status'] = self.order_status.to_alipay_dict()
            else:
                params['order_status'] = self.order_status
        if self.refund_info:
            if hasattr(self.refund_info, 'to_alipay_dict'):
                params['refund_info'] = self.refund_info.to_alipay_dict()
            else:
                params['refund_info'] = self.refund_info
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEducateBillServiceModifyModel()
        if 'isv_order_no' in d:
            o.isv_order_no = d['isv_order_no']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'order_status' in d:
            o.order_status = d['order_status']
        if 'refund_info' in d:
            o.refund_info = d['refund_info']
        if 'source' in d:
            o.source = d['source']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniInnerSafedomainCreateModel(object):

    def __init__(self):
        self._app_origin = None
        self._dev_id = None
        self._mini_app_id = None
        self._mini_app_safe_domain = None

    @property
    def app_origin(self):
        return self._app_origin

    @app_origin.setter
    def app_origin(self, value):
        self._app_origin = value
    @property
    def dev_id(self):
        return self._dev_id

    @dev_id.setter
    def dev_id(self, value):
        self._dev_id = value
    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def mini_app_safe_domain(self):
        return self._mini_app_safe_domain

    @mini_app_safe_domain.setter
    def mini_app_safe_domain(self, value):
        self._mini_app_safe_domain = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_origin:
            if hasattr(self.app_origin, 'to_alipay_dict'):
                params['app_origin'] = self.app_origin.to_alipay_dict()
            else:
                params['app_origin'] = self.app_origin
        if self.dev_id:
            if hasattr(self.dev_id, 'to_alipay_dict'):
                params['dev_id'] = self.dev_id.to_alipay_dict()
            else:
                params['dev_id'] = self.dev_id
        if self.mini_app_id:
            if hasattr(self.mini_app_id, 'to_alipay_dict'):
                params['mini_app_id'] = self.mini_app_id.to_alipay_dict()
            else:
                params['mini_app_id'] = self.mini_app_id
        if self.mini_app_safe_domain:
            if hasattr(self.mini_app_safe_domain, 'to_alipay_dict'):
                params['mini_app_safe_domain'] = self.mini_app_safe_domain.to_alipay_dict()
            else:
                params['mini_app_safe_domain'] = self.mini_app_safe_domain
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniInnerSafedomainCreateModel()
        if 'app_origin' in d:
            o.app_origin = d['app_origin']
        if 'dev_id' in d:
            o.dev_id = d['dev_id']
        if 'mini_app_id' in d:
            o.mini_app_id = d['mini_app_id']
        if 'mini_app_safe_domain' in d:
            o.mini_app_safe_domain = d['mini_app_safe_domain']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class FundBill(object):

    def __init__(self):
        self._amount = None
        self._bank_code = None
        self._fund_channel = None
        self._real_amount = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def bank_code(self):
        return self._bank_code

    @bank_code.setter
    def bank_code(self, value):
        self._bank_code = value
    @property
    def fund_channel(self):
        return self._fund_channel

    @fund_channel.setter
    def fund_channel(self, value):
        self._fund_channel = value
    @property
    def real_amount(self):
        return self._real_amount

    @real_amount.setter
    def real_amount(self, value):
        self._real_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.bank_code:
            if hasattr(self.bank_code, 'to_alipay_dict'):
                params['bank_code'] = self.bank_code.to_alipay_dict()
            else:
                params['bank_code'] = self.bank_code
        if self.fund_channel:
            if hasattr(self.fund_channel, 'to_alipay_dict'):
                params['fund_channel'] = self.fund_channel.to_alipay_dict()
            else:
                params['fund_channel'] = self.fund_channel
        if self.real_amount:
            if hasattr(self.real_amount, 'to_alipay_dict'):
                params['real_amount'] = self.real_amount.to_alipay_dict()
            else:
                params['real_amount'] = self.real_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FundBill()
        if 'amount' in d:
            o.amount = d['amount']
        if 'bank_code' in d:
            o.bank_code = d['bank_code']
        if 'fund_channel' in d:
            o.fund_channel = d['fund_channel']
        if 'real_amount' in d:
            o.real_amount = d['real_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CreateESignTaskFileVO import CreateESignTaskFileVO


class ApprovalFlowInfoDTO(object):

    def __init__(self):
        self._approve_status = None
        self._approve_time = None
        self._approver = None
        self._attachement_list = None
        self._comments = None
        self._index = None
        self._node = None

    @property
    def approve_status(self):
        return self._approve_status

    @approve_status.setter
    def approve_status(self, value):
        self._approve_status = value
    @property
    def approve_time(self):
        return self._approve_time

    @approve_time.setter
    def approve_time(self, value):
        self._approve_time = value
    @property
    def approver(self):
        return self._approver

    @approver.setter
    def approver(self, value):
        self._approver = value
    @property
    def attachement_list(self):
        return self._attachement_list

    @attachement_list.setter
    def attachement_list(self, value):
        if isinstance(value, list):
            self._attachement_list = list()
            for i in value:
                if isinstance(i, CreateESignTaskFileVO):
                    self._attachement_list.append(i)
                else:
                    self._attachement_list.append(CreateESignTaskFileVO.from_alipay_dict(i))
    @property
    def comments(self):
        return self._comments

    @comments.setter
    def comments(self, value):
        self._comments = value
    @property
    def index(self):
        return self._index

    @index.setter
    def index(self, value):
        self._index = value
    @property
    def node(self):
        return self._node

    @node.setter
    def node(self, value):
        self._node = value


    def to_alipay_dict(self):
        params = dict()
        if self.approve_status:
            if hasattr(self.approve_status, 'to_alipay_dict'):
                params['approve_status'] = self.approve_status.to_alipay_dict()
            else:
                params['approve_status'] = self.approve_status
        if self.approve_time:
            if hasattr(self.approve_time, 'to_alipay_dict'):
                params['approve_time'] = self.approve_time.to_alipay_dict()
            else:
                params['approve_time'] = self.approve_time
        if self.approver:
            if hasattr(self.approver, 'to_alipay_dict'):
                params['approver'] = self.approver.to_alipay_dict()
            else:
                params['approver'] = self.approver
        if self.attachement_list:
            if isinstance(self.attachement_list, list):
                for i in range(0, len(self.attachement_list)):
                    element = self.attachement_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.attachement_list[i] = element.to_alipay_dict()
            if hasattr(self.attachement_list, 'to_alipay_dict'):
                params['attachement_list'] = self.attachement_list.to_alipay_dict()
            else:
                params['attachement_list'] = self.attachement_list
        if self.comments:
            if hasattr(self.comments, 'to_alipay_dict'):
                params['comments'] = self.comments.to_alipay_dict()
            else:
                params['comments'] = self.comments
        if self.index:
            if hasattr(self.index, 'to_alipay_dict'):
                params['index'] = self.index.to_alipay_dict()
            else:
                params['index'] = self.index
        if self.node:
            if hasattr(self.node, 'to_alipay_dict'):
                params['node'] = self.node.to_alipay_dict()
            else:
                params['node'] = self.node
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ApprovalFlowInfoDTO()
        if 'approve_status' in d:
            o.approve_status = d['approve_status']
        if 'approve_time' in d:
            o.approve_time = d['approve_time']
        if 'approver' in d:
            o.approver = d['approver']
        if 'attachement_list' in d:
            o.attachement_list = d['attachement_list']
        if 'comments' in d:
            o.comments = d['comments']
        if 'index' in d:
            o.index = d['index']
        if 'node' in d:
            o.node = d['node']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PetPhoto import PetPhoto


class AlipayInsScenePetprofilePlatformprofileCreateModel(object):

    def __init__(self):
        self._birthday = None
        self._gender = None
        self._nick = None
        self._out_biz_no = None
        self._photos = None
        self._sterilization = None
        self._type = None

    @property
    def birthday(self):
        return self._birthday

    @birthday.setter
    def birthday(self, value):
        self._birthday = value
    @property
    def gender(self):
        return self._gender

    @gender.setter
    def gender(self, value):
        self._gender = value
    @property
    def nick(self):
        return self._nick

    @nick.setter
    def nick(self, value):
        self._nick = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def photos(self):
        return self._photos

    @photos.setter
    def photos(self, value):
        if isinstance(value, list):
            self._photos = list()
            for i in value:
                if isinstance(i, PetPhoto):
                    self._photos.append(i)
                else:
                    self._photos.append(PetPhoto.from_alipay_dict(i))
    @property
    def sterilization(self):
        return self._sterilization

    @sterilization.setter
    def sterilization(self, value):
        self._sterilization = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.birthday:
            if hasattr(self.birthday, 'to_alipay_dict'):
                params['birthday'] = self.birthday.to_alipay_dict()
            else:
                params['birthday'] = self.birthday
        if self.gender:
            if hasattr(self.gender, 'to_alipay_dict'):
                params['gender'] = self.gender.to_alipay_dict()
            else:
                params['gender'] = self.gender
        if self.nick:
            if hasattr(self.nick, 'to_alipay_dict'):
                params['nick'] = self.nick.to_alipay_dict()
            else:
                params['nick'] = self.nick
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.photos:
            if isinstance(self.photos, list):
                for i in range(0, len(self.photos)):
                    element = self.photos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.photos[i] = element.to_alipay_dict()
            if hasattr(self.photos, 'to_alipay_dict'):
                params['photos'] = self.photos.to_alipay_dict()
            else:
                params['photos'] = self.photos
        if self.sterilization:
            if hasattr(self.sterilization, 'to_alipay_dict'):
                params['sterilization'] = self.sterilization.to_alipay_dict()
            else:
                params['sterilization'] = self.sterilization
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsScenePetprofilePlatformprofileCreateModel()
        if 'birthday' in d:
            o.birthday = d['birthday']
        if 'gender' in d:
            o.gender = d['gender']
        if 'nick' in d:
            o.nick = d['nick']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'photos' in d:
            o.photos = d['photos']
        if 'sterilization' in d:
            o.sterilization = d['sterilization']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.KbAdvertCommissionClause import KbAdvertCommissionClause


class KbAdvertMissionSubject(object):

    def __init__(self):
        self._commission_clause_list = None
        self._subject_biz_id = None
        self._subject_type = None

    @property
    def commission_clause_list(self):
        return self._commission_clause_list

    @commission_clause_list.setter
    def commission_clause_list(self, value):
        if isinstance(value, list):
            self._commission_clause_list = list()
            for i in value:
                if isinstance(i, KbAdvertCommissionClause):
                    self._commission_clause_list.append(i)
                else:
                    self._commission_clause_list.append(KbAdvertCommissionClause.from_alipay_dict(i))
    @property
    def subject_biz_id(self):
        return self._subject_biz_id

    @subject_biz_id.setter
    def subject_biz_id(self, value):
        self._subject_biz_id = value
    @property
    def subject_type(self):
        return self._subject_type

    @subject_type.setter
    def subject_type(self, value):
        self._subject_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.commission_clause_list:
            if isinstance(self.commission_clause_list, list):
                for i in range(0, len(self.commission_clause_list)):
                    element = self.commission_clause_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.commission_clause_list[i] = element.to_alipay_dict()
            if hasattr(self.commission_clause_list, 'to_alipay_dict'):
                params['commission_clause_list'] = self.commission_clause_list.to_alipay_dict()
            else:
                params['commission_clause_list'] = self.commission_clause_list
        if self.subject_biz_id:
            if hasattr(self.subject_biz_id, 'to_alipay_dict'):
                params['subject_biz_id'] = self.subject_biz_id.to_alipay_dict()
            else:
                params['subject_biz_id'] = self.subject_biz_id
        if self.subject_type:
            if hasattr(self.subject_type, 'to_alipay_dict'):
                params['subject_type'] = self.subject_type.to_alipay_dict()
            else:
                params['subject_type'] = self.subject_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KbAdvertMissionSubject()
        if 'commission_clause_list' in d:
            o.commission_clause_list = d['commission_clause_list']
        if 'subject_biz_id' in d:
            o.subject_biz_id = d['subject_biz_id']
        if 'subject_type' in d:
            o.subject_type = d['subject_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MultiCurrencyMoneyVO import MultiCurrencyMoneyVO
from alipay.aop.api.domain.LoanPayConsultOrder import LoanPayConsultOrder
from alipay.aop.api.domain.LoanPayUser import LoanPayUser


class MybankCreditLoantradeLoanpayAssetConsultModel(object):

    def __init__(self):
        self._alipay_partner_id = None
        self._apply_amt = None
        self._order_info = None
        self._payment_sale_pd_code = None
        self._platform_type = None
        self._sub_platform_type = None
        self._user = None

    @property
    def alipay_partner_id(self):
        return self._alipay_partner_id

    @alipay_partner_id.setter
    def alipay_partner_id(self, value):
        self._alipay_partner_id = value
    @property
    def apply_amt(self):
        return self._apply_amt

    @apply_amt.setter
    def apply_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyVO):
            self._apply_amt = value
        else:
            self._apply_amt = MultiCurrencyMoneyVO.from_alipay_dict(value)
    @property
    def order_info(self):
        return self._order_info

    @order_info.setter
    def order_info(self, value):
        if isinstance(value, list):
            self._order_info = list()
            for i in value:
                if isinstance(i, LoanPayConsultOrder):
                    self._order_info.append(i)
                else:
                    self._order_info.append(LoanPayConsultOrder.from_alipay_dict(i))
    @property
    def payment_sale_pd_code(self):
        return self._payment_sale_pd_code

    @payment_sale_pd_code.setter
    def payment_sale_pd_code(self, value):
        self._payment_sale_pd_code = value
    @property
    def platform_type(self):
        return self._platform_type

    @platform_type.setter
    def platform_type(self, value):
        self._platform_type = value
    @property
    def sub_platform_type(self):
        return self._sub_platform_type

    @sub_platform_type.setter
    def sub_platform_type(self, value):
        self._sub_platform_type = value
    @property
    def user(self):
        return self._user

    @user.setter
    def user(self, value):
        if isinstance(value, LoanPayUser):
            self._user = value
        else:
            self._user = LoanPayUser.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_partner_id:
            if hasattr(self.alipay_partner_id, 'to_alipay_dict'):
                params['alipay_partner_id'] = self.alipay_partner_id.to_alipay_dict()
            else:
                params['alipay_partner_id'] = self.alipay_partner_id
        if self.apply_amt:
            if hasattr(self.apply_amt, 'to_alipay_dict'):
                params['apply_amt'] = self.apply_amt.to_alipay_dict()
            else:
                params['apply_amt'] = self.apply_amt
        if self.order_info:
            if isinstance(self.order_info, list):
                for i in range(0, len(self.order_info)):
                    element = self.order_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.order_info[i] = element.to_alipay_dict()
            if hasattr(self.order_info, 'to_alipay_dict'):
                params['order_info'] = self.order_info.to_alipay_dict()
            else:
                params['order_info'] = self.order_info
        if self.payment_sale_pd_code:
            if hasattr(self.payment_sale_pd_code, 'to_alipay_dict'):
                params['payment_sale_pd_code'] = self.payment_sale_pd_code.to_alipay_dict()
            else:
                params['payment_sale_pd_code'] = self.payment_sale_pd_code
        if self.platform_type:
            if hasattr(self.platform_type, 'to_alipay_dict'):
                params['platform_type'] = self.platform_type.to_alipay_dict()
            else:
                params['platform_type'] = self.platform_type
        if self.sub_platform_type:
            if hasattr(self.sub_platform_type, 'to_alipay_dict'):
                params['sub_platform_type'] = self.sub_platform_type.to_alipay_dict()
            else:
                params['sub_platform_type'] = self.sub_platform_type
        if self.user:
            if hasattr(self.user, 'to_alipay_dict'):
                params['user'] = self.user.to_alipay_dict()
            else:
                params['user'] = self.user
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditLoantradeLoanpayAssetConsultModel()
        if 'alipay_partner_id' in d:
            o.alipay_partner_id = d['alipay_partner_id']
        if 'apply_amt' in d:
            o.apply_amt = d['apply_amt']
        if 'order_info' in d:
            o.order_info = d['order_info']
        if 'payment_sale_pd_code' in d:
            o.payment_sale_pd_code = d['payment_sale_pd_code']
        if 'platform_type' in d:
            o.platform_type = d['platform_type']
        if 'sub_platform_type' in d:
            o.sub_platform_type = d['sub_platform_type']
        if 'user' in d:
            o.user = d['user']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.LinkTypeResult import LinkTypeResult


class LinkTypeListResult(object):

    def __init__(self):
        self._link_type_list = None

    @property
    def link_type_list(self):
        return self._link_type_list

    @link_type_list.setter
    def link_type_list(self, value):
        if isinstance(value, list):
            self._link_type_list = list()
            for i in value:
                if isinstance(i, LinkTypeResult):
                    self._link_type_list.append(i)
                else:
                    self._link_type_list.append(LinkTypeResult.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.link_type_list:
            if isinstance(self.link_type_list, list):
                for i in range(0, len(self.link_type_list)):
                    element = self.link_type_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.link_type_list[i] = element.to_alipay_dict()
            if hasattr(self.link_type_list, 'to_alipay_dict'):
                params['link_type_list'] = self.link_type_list.to_alipay_dict()
            else:
                params['link_type_list'] = self.link_type_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = LinkTypeListResult()
        if 'link_type_list' in d:
            o.link_type_list = d['link_type_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class Operator(object):

    def __init__(self):
        self._emp_id = None
        self._nick_name = None

    @property
    def emp_id(self):
        return self._emp_id

    @emp_id.setter
    def emp_id(self, value):
        self._emp_id = value
    @property
    def nick_name(self):
        return self._nick_name

    @nick_name.setter
    def nick_name(self, value):
        self._nick_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.emp_id:
            if hasattr(self.emp_id, 'to_alipay_dict'):
                params['emp_id'] = self.emp_id.to_alipay_dict()
            else:
                params['emp_id'] = self.emp_id
        if self.nick_name:
            if hasattr(self.nick_name, 'to_alipay_dict'):
                params['nick_name'] = self.nick_name.to_alipay_dict()
            else:
                params['nick_name'] = self.nick_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = Operator()
        if 'emp_id' in d:
            o.emp_id = d['emp_id']
        if 'nick_name' in d:
            o.nick_name = d['nick_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BusinessParams import BusinessParams
from alipay.aop.api.domain.ExtendParams import ExtendParams
from alipay.aop.api.domain.GoodsDetail import GoodsDetail
from alipay.aop.api.domain.RoyaltyInfo import RoyaltyInfo
from alipay.aop.api.domain.SettleInfo import SettleInfo


class AlipayTradeOrderPrepayModel(object):

    def __init__(self):
        self._body = None
        self._business_params = None
        self._extend_params = None
        self._goods_detail = None
        self._order_scene = None
        self._out_trade_no = None
        self._product_code = None
        self._royalty_info = None
        self._seller_id = None
        self._settle_info = None
        self._subject = None
        self._time_expire = None
        self._timeout_express = None
        self._total_amount = None

    @property
    def body(self):
        return self._body

    @body.setter
    def body(self, value):
        self._body = value
    @property
    def business_params(self):
        return self._business_params

    @business_params.setter
    def business_params(self, value):
        if isinstance(value, BusinessParams):
            self._business_params = value
        else:
            self._business_params = BusinessParams.from_alipay_dict(value)
    @property
    def extend_params(self):
        return self._extend_params

    @extend_params.setter
    def extend_params(self, value):
        if isinstance(value, ExtendParams):
            self._extend_params = value
        else:
            self._extend_params = ExtendParams.from_alipay_dict(value)
    @property
    def goods_detail(self):
        return self._goods_detail

    @goods_detail.setter
    def goods_detail(self, value):
        if isinstance(value, list):
            self._goods_detail = list()
            for i in value:
                if isinstance(i, GoodsDetail):
                    self._goods_detail.append(i)
                else:
                    self._goods_detail.append(GoodsDetail.from_alipay_dict(i))
    @property
    def order_scene(self):
        return self._order_scene

    @order_scene.setter
    def order_scene(self, value):
        self._order_scene = value
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def royalty_info(self):
        return self._royalty_info

    @royalty_info.setter
    def royalty_info(self, value):
        if isinstance(value, RoyaltyInfo):
            self._royalty_info = value
        else:
            self._royalty_info = RoyaltyInfo.from_alipay_dict(value)
    @property
    def seller_id(self):
        return self._seller_id

    @seller_id.setter
    def seller_id(self, value):
        self._seller_id = value
    @property
    def settle_info(self):
        return self._settle_info

    @settle_info.setter
    def settle_info(self, value):
        if isinstance(value, SettleInfo):
            self._settle_info = value
        else:
            self._settle_info = SettleInfo.from_alipay_dict(value)
    @property
    def subject(self):
        return self._subject

    @subject.setter
    def subject(self, value):
        self._subject = value
    @property
    def time_expire(self):
        return self._time_expire

    @time_expire.setter
    def time_expire(self, value):
        self._time_expire = value
    @property
    def timeout_express(self):
        return self._timeout_express

    @timeout_express.setter
    def timeout_express(self, value):
        self._timeout_express = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.body:
            if hasattr(self.body, 'to_alipay_dict'):
                params['body'] = self.body.to_alipay_dict()
            else:
                params['body'] = self.body
        if self.business_params:
            if hasattr(self.business_params, 'to_alipay_dict'):
                params['business_params'] = self.business_params.to_alipay_dict()
            else:
                params['business_params'] = self.business_params
        if self.extend_params:
            if hasattr(self.extend_params, 'to_alipay_dict'):
                params['extend_params'] = self.extend_params.to_alipay_dict()
            else:
                params['extend_params'] = self.extend_params
        if self.goods_detail:
            if isinstance(self.goods_detail, list):
                for i in range(0, len(self.goods_detail)):
                    element = self.goods_detail[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.goods_detail[i] = element.to_alipay_dict()
            if hasattr(self.goods_detail, 'to_alipay_dict'):
                params['goods_detail'] = self.goods_detail.to_alipay_dict()
            else:
                params['goods_detail'] = self.goods_detail
        if self.order_scene:
            if hasattr(self.order_scene, 'to_alipay_dict'):
                params['order_scene'] = self.order_scene.to_alipay_dict()
            else:
                params['order_scene'] = self.order_scene
        if self.out_trade_no:
            if hasattr(self.out_trade_no, 'to_alipay_dict'):
                params['out_trade_no'] = self.out_trade_no.to_alipay_dict()
            else:
                params['out_trade_no'] = self.out_trade_no
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.royalty_info:
            if hasattr(self.royalty_info, 'to_alipay_dict'):
                params['royalty_info'] = self.royalty_info.to_alipay_dict()
            else:
                params['royalty_info'] = self.royalty_info
        if self.seller_id:
            if hasattr(self.seller_id, 'to_alipay_dict'):
                params['seller_id'] = self.seller_id.to_alipay_dict()
            else:
                params['seller_id'] = self.seller_id
        if self.settle_info:
            if hasattr(self.settle_info, 'to_alipay_dict'):
                params['settle_info'] = self.settle_info.to_alipay_dict()
            else:
                params['settle_info'] = self.settle_info
        if self.subject:
            if hasattr(self.subject, 'to_alipay_dict'):
                params['subject'] = self.subject.to_alipay_dict()
            else:
                params['subject'] = self.subject
        if self.time_expire:
            if hasattr(self.time_expire, 'to_alipay_dict'):
                params['time_expire'] = self.time_expire.to_alipay_dict()
            else:
                params['time_expire'] = self.time_expire
        if self.timeout_express:
            if hasattr(self.timeout_express, 'to_alipay_dict'):
                params['timeout_express'] = self.timeout_express.to_alipay_dict()
            else:
                params['timeout_express'] = self.timeout_express
        if self.total_amount:
            if hasattr(self.total_amount, 'to_alipay_dict'):
                params['total_amount'] = self.total_amount.to_alipay_dict()
            else:
                params['total_amount'] = self.total_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayTradeOrderPrepayModel()
        if 'body' in d:
            o.body = d['body']
        if 'business_params' in d:
            o.business_params = d['business_params']
        if 'extend_params' in d:
            o.extend_params = d['extend_params']
        if 'goods_detail' in d:
            o.goods_detail = d['goods_detail']
        if 'order_scene' in d:
            o.order_scene = d['order_scene']
        if 'out_trade_no' in d:
            o.out_trade_no = d['out_trade_no']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'royalty_info' in d:
            o.royalty_info = d['royalty_info']
        if 'seller_id' in d:
            o.seller_id = d['seller_id']
        if 'settle_info' in d:
            o.settle_info = d['settle_info']
        if 'subject' in d:
            o.subject = d['subject']
        if 'time_expire' in d:
            o.time_expire = d['time_expire']
        if 'timeout_express' in d:
            o.timeout_express = d['timeout_express']
        if 'total_amount' in d:
            o.total_amount = d['total_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AosHotItem(object):

    def __init__(self):
        self._image = None
        self._score = None
        self._sequence = None
        self._title = None
        self._trace_id = None

    @property
    def image(self):
        return self._image

    @image.setter
    def image(self, value):
        self._image = value
    @property
    def score(self):
        return self._score

    @score.setter
    def score(self, value):
        self._score = value
    @property
    def sequence(self):
        return self._sequence

    @sequence.setter
    def sequence(self, value):
        self._sequence = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.image:
            if hasattr(self.image, 'to_alipay_dict'):
                params['image'] = self.image.to_alipay_dict()
            else:
                params['image'] = self.image
        if self.score:
            if hasattr(self.score, 'to_alipay_dict'):
                params['score'] = self.score.to_alipay_dict()
            else:
                params['score'] = self.score
        if self.sequence:
            if hasattr(self.sequence, 'to_alipay_dict'):
                params['sequence'] = self.sequence.to_alipay_dict()
            else:
                params['sequence'] = self.sequence
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.trace_id:
            if hasattr(self.trace_id, 'to_alipay_dict'):
                params['trace_id'] = self.trace_id.to_alipay_dict()
            else:
                params['trace_id'] = self.trace_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AosHotItem()
        if 'image' in d:
            o.image = d['image']
        if 'score' in d:
            o.score = d['score']
        if 'sequence' in d:
            o.sequence = d['sequence']
        if 'title' in d:
            o.title = d['title']
        if 'trace_id' in d:
            o.trace_id = d['trace_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayInsSceneInsserviceprodSerattachmentUploadResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsSceneInsserviceprodSerattachmentUploadResponse, self).__init__()
        self._attachment_no = None

    @property
    def attachment_no(self):
        return self._attachment_no

    @attachment_no.setter
    def attachment_no(self, value):
        self._attachment_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayInsSceneInsserviceprodSerattachmentUploadResponse, self).parse_response_content(response_content)
        if 'attachment_no' in response:
            self.attachment_no = response['attachment_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi
from alipay.aop.api.domain.InvoiceBillItem import InvoiceBillItem
from alipay.aop.api.domain.OutputApplyInvoiceDetailOrder import OutputApplyInvoiceDetailOrder
from alipay.aop.api.domain.InvoiceApplyOpenApi import InvoiceApplyOpenApi


class AlipayBossFncOutputinvoicePreviewModel(object):

    def __init__(self):
        self._biz_id = None
        self._biz_no = None
        self._invoice_amt = None
        self._invoice_bill_items = None
        self._invoice_note = None
        self._mail_id = None
        self._memo = None
        self._operator = None
        self._output_apply_invoice_detail_orders = None
        self._output_invoice_apply_orders = None
        self._source = None

    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def invoice_amt(self):
        return self._invoice_amt

    @invoice_amt.setter
    def invoice_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._invoice_amt = value
        else:
            self._invoice_amt = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def invoice_bill_items(self):
        return self._invoice_bill_items

    @invoice_bill_items.setter
    def invoice_bill_items(self, value):
        if isinstance(value, list):
            self._invoice_bill_items = list()
            for i in value:
                if isinstance(i, InvoiceBillItem):
                    self._invoice_bill_items.append(i)
                else:
                    self._invoice_bill_items.append(InvoiceBillItem.from_alipay_dict(i))
    @property
    def invoice_note(self):
        return self._invoice_note

    @invoice_note.setter
    def invoice_note(self, value):
        self._invoice_note = value
    @property
    def mail_id(self):
        return self._mail_id

    @mail_id.setter
    def mail_id(self, value):
        self._mail_id = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        self._operator = value
    @property
    def output_apply_invoice_detail_orders(self):
        return self._output_apply_invoice_detail_orders

    @output_apply_invoice_detail_orders.setter
    def output_apply_invoice_detail_orders(self, value):
        if isinstance(value, list):
            self._output_apply_invoice_detail_orders = list()
            for i in value:
                if isinstance(i, OutputApplyInvoiceDetailOrder):
                    self._output_apply_invoice_detail_orders.append(i)
                else:
                    self._output_apply_invoice_detail_orders.append(OutputApplyInvoiceDetailOrder.from_alipay_dict(i))
    @property
    def output_invoice_apply_orders(self):
        return self._output_invoice_apply_orders

    @output_invoice_apply_orders.setter
    def output_invoice_apply_orders(self, value):
        if isinstance(value, list):
            self._output_invoice_apply_orders = list()
            for i in value:
                if isinstance(i, InvoiceApplyOpenApi):
                    self._output_invoice_apply_orders.append(i)
                else:
                    self._output_invoice_apply_orders.append(InvoiceApplyOpenApi.from_alipay_dict(i))
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.biz_no:
            if hasattr(self.biz_no, 'to_alipay_dict'):
                params['biz_no'] = self.biz_no.to_alipay_dict()
            else:
                params['biz_no'] = self.biz_no
        if self.invoice_amt:
            if hasattr(self.invoice_amt, 'to_alipay_dict'):
                params['invoice_amt'] = self.invoice_amt.to_alipay_dict()
            else:
                params['invoice_amt'] = self.invoice_amt
        if self.invoice_bill_items:
            if isinstance(self.invoice_bill_items, list):
                for i in range(0, len(self.invoice_bill_items)):
                    element = self.invoice_bill_items[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.invoice_bill_items[i] = element.to_alipay_dict()
            if hasattr(self.invoice_bill_items, 'to_alipay_dict'):
                params['invoice_bill_items'] = self.invoice_bill_items.to_alipay_dict()
            else:
                params['invoice_bill_items'] = self.invoice_bill_items
        if self.invoice_note:
            if hasattr(self.invoice_note, 'to_alipay_dict'):
                params['invoice_note'] = self.invoice_note.to_alipay_dict()
            else:
                params['invoice_note'] = self.invoice_note
        if self.mail_id:
            if hasattr(self.mail_id, 'to_alipay_dict'):
                params['mail_id'] = self.mail_id.to_alipay_dict()
            else:
                params['mail_id'] = self.mail_id
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = self.operator.to_alipay_dict()
            else:
                params['operator'] = self.operator
        if self.output_apply_invoice_detail_orders:
            if isinstance(self.output_apply_invoice_detail_orders, list):
                for i in range(0, len(self.output_apply_invoice_detail_orders)):
                    element = self.output_apply_invoice_detail_orders[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.output_apply_invoice_detail_orders[i] = element.to_alipay_dict()
            if hasattr(self.output_apply_invoice_detail_orders, 'to_alipay_dict'):
                params['output_apply_invoice_detail_orders'] = self.output_apply_invoice_detail_orders.to_alipay_dict()
            else:
                params['output_apply_invoice_detail_orders'] = self.output_apply_invoice_detail_orders
        if self.output_invoice_apply_orders:
            if isinstance(self.output_invoice_apply_orders, list):
                for i in range(0, len(self.output_invoice_apply_orders)):
                    element = self.output_invoice_apply_orders[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.output_invoice_apply_orders[i] = element.to_alipay_dict()
            if hasattr(self.output_invoice_apply_orders, 'to_alipay_dict'):
                params['output_invoice_apply_orders'] = self.output_invoice_apply_orders.to_alipay_dict()
            else:
                params['output_invoice_apply_orders'] = self.output_invoice_apply_orders
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncOutputinvoicePreviewModel()
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'biz_no' in d:
            o.biz_no = d['biz_no']
        if 'invoice_amt' in d:
            o.invoice_amt = d['invoice_amt']
        if 'invoice_bill_items' in d:
            o.invoice_bill_items = d['invoice_bill_items']
        if 'invoice_note' in d:
            o.invoice_note = d['invoice_note']
        if 'mail_id' in d:
            o.mail_id = d['mail_id']
        if 'memo' in d:
            o.memo = d['memo']
        if 'operator' in d:
            o.operator = d['operator']
        if 'output_apply_invoice_detail_orders' in d:
            o.output_apply_invoice_detail_orders = d['output_apply_invoice_detail_orders']
        if 'output_invoice_apply_orders' in d:
            o.output_invoice_apply_orders = d['output_invoice_apply_orders']
        if 'source' in d:
            o.source = d['source']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DiscountDstCampPrizeModel(object):

    def __init__(self):
        self._budget_id = None
        self._discount_rate = None
        self._id = None
        self._max_discount_amt = None

    @property
    def budget_id(self):
        return self._budget_id

    @budget_id.setter
    def budget_id(self, value):
        self._budget_id = value
    @property
    def discount_rate(self):
        return self._discount_rate

    @discount_rate.setter
    def discount_rate(self, value):
        self._discount_rate = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def max_discount_amt(self):
        return self._max_discount_amt

    @max_discount_amt.setter
    def max_discount_amt(self, value):
        self._max_discount_amt = value


    def to_alipay_dict(self):
        params = dict()
        if self.budget_id:
            if hasattr(self.budget_id, 'to_alipay_dict'):
                params['budget_id'] = self.budget_id.to_alipay_dict()
            else:
                params['budget_id'] = self.budget_id
        if self.discount_rate:
            if hasattr(self.discount_rate, 'to_alipay_dict'):
                params['discount_rate'] = self.discount_rate.to_alipay_dict()
            else:
                params['discount_rate'] = self.discount_rate
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.max_discount_amt:
            if hasattr(self.max_discount_amt, 'to_alipay_dict'):
                params['max_discount_amt'] = self.max_discount_amt.to_alipay_dict()
            else:
                params['max_discount_amt'] = self.max_discount_amt
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DiscountDstCampPrizeModel()
        if 'budget_id' in d:
            o.budget_id = d['budget_id']
        if 'discount_rate' in d:
            o.discount_rate = d['discount_rate']
        if 'id' in d:
            o.id = d['id']
        if 'max_discount_amt' in d:
            o.max_discount_amt = d['max_discount_amt']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BPOpenApiAddSignContent(object):

    def __init__(self):
        self._additional_lines = None
        self._assignee = None
        self._deal_actions = None
        self._deal_url = None
        self._detail_url = None
        self._display_name = None

    @property
    def additional_lines(self):
        return self._additional_lines

    @additional_lines.setter
    def additional_lines(self, value):
        if isinstance(value, list):
            self._additional_lines = list()
            for i in value:
                self._additional_lines.append(i)
    @property
    def assignee(self):
        return self._assignee

    @assignee.setter
    def assignee(self, value):
        self._assignee = value
    @property
    def deal_actions(self):
        return self._deal_actions

    @deal_actions.setter
    def deal_actions(self, value):
        self._deal_actions = value
    @property
    def deal_url(self):
        return self._deal_url

    @deal_url.setter
    def deal_url(self, value):
        self._deal_url = value
    @property
    def detail_url(self):
        return self._detail_url

    @detail_url.setter
    def detail_url(self, value):
        self._detail_url = value
    @property
    def display_name(self):
        return self._display_name

    @display_name.setter
    def display_name(self, value):
        self._display_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.additional_lines:
            if isinstance(self.additional_lines, list):
                for i in range(0, len(self.additional_lines)):
                    element = self.additional_lines[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.additional_lines[i] = element.to_alipay_dict()
            if hasattr(self.additional_lines, 'to_alipay_dict'):
                params['additional_lines'] = self.additional_lines.to_alipay_dict()
            else:
                params['additional_lines'] = self.additional_lines
        if self.assignee:
            if hasattr(self.assignee, 'to_alipay_dict'):
                params['assignee'] = self.assignee.to_alipay_dict()
            else:
                params['assignee'] = self.assignee
        if self.deal_actions:
            if hasattr(self.deal_actions, 'to_alipay_dict'):
                params['deal_actions'] = self.deal_actions.to_alipay_dict()
            else:
                params['deal_actions'] = self.deal_actions
        if self.deal_url:
            if hasattr(self.deal_url, 'to_alipay_dict'):
                params['deal_url'] = self.deal_url.to_alipay_dict()
            else:
                params['deal_url'] = self.deal_url
        if self.detail_url:
            if hasattr(self.detail_url, 'to_alipay_dict'):
                params['detail_url'] = self.detail_url.to_alipay_dict()
            else:
                params['detail_url'] = self.detail_url
        if self.display_name:
            if hasattr(self.display_name, 'to_alipay_dict'):
                params['display_name'] = self.display_name.to_alipay_dict()
            else:
                params['display_name'] = self.display_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BPOpenApiAddSignContent()
        if 'additional_lines' in d:
            o.additional_lines = d['additional_lines']
        if 'assignee' in d:
            o.assignee = d['assignee']
        if 'deal_actions' in d:
            o.deal_actions = d['deal_actions']
        if 'deal_url' in d:
            o.deal_url = d['deal_url']
        if 'detail_url' in d:
            o.detail_url = d['detail_url']
        if 'display_name' in d:
            o.display_name = d['display_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayInsSceneCommonPolicyCancelResponse(AlipayResponse):

    def __init__(self):
        super(AlipayInsSceneCommonPolicyCancelResponse, self).__init__()
        self._endorse_no = None

    @property
    def endorse_no(self):
        return self._endorse_no

    @endorse_no.setter
    def endorse_no(self, value):
        self._endorse_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayInsSceneCommonPolicyCancelResponse, self).parse_response_content(response_content)
        if 'endorse_no' in response:
            self.endorse_no = response['endorse_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.EcoApplySchedule import EcoApplySchedule


class AlipayEcoRenthousePublicrentApplyscheduleSyncModel(object):

    def __init__(self):
        self._apply_schedule_list = None
        self._cert_no = None
        self._rent_id = None

    @property
    def apply_schedule_list(self):
        return self._apply_schedule_list

    @apply_schedule_list.setter
    def apply_schedule_list(self, value):
        if isinstance(value, list):
            self._apply_schedule_list = list()
            for i in value:
                if isinstance(i, EcoApplySchedule):
                    self._apply_schedule_list.append(i)
                else:
                    self._apply_schedule_list.append(EcoApplySchedule.from_alipay_dict(i))
    @property
    def cert_no(self):
        return self._cert_no

    @cert_no.setter
    def cert_no(self, value):
        self._cert_no = value
    @property
    def rent_id(self):
        return self._rent_id

    @rent_id.setter
    def rent_id(self, value):
        self._rent_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_schedule_list:
            if isinstance(self.apply_schedule_list, list):
                for i in range(0, len(self.apply_schedule_list)):
                    element = self.apply_schedule_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.apply_schedule_list[i] = element.to_alipay_dict()
            if hasattr(self.apply_schedule_list, 'to_alipay_dict'):
                params['apply_schedule_list'] = self.apply_schedule_list.to_alipay_dict()
            else:
                params['apply_schedule_list'] = self.apply_schedule_list
        if self.cert_no:
            if hasattr(self.cert_no, 'to_alipay_dict'):
                params['cert_no'] = self.cert_no.to_alipay_dict()
            else:
                params['cert_no'] = self.cert_no
        if self.rent_id:
            if hasattr(self.rent_id, 'to_alipay_dict'):
                params['rent_id'] = self.rent_id.to_alipay_dict()
            else:
                params['rent_id'] = self.rent_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoRenthousePublicrentApplyscheduleSyncModel()
        if 'apply_schedule_list' in d:
            o.apply_schedule_list = d['apply_schedule_list']
        if 'cert_no' in d:
            o.cert_no = d['cert_no']
        if 'rent_id' in d:
            o.rent_id = d['rent_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DeliveryOrderProcessVO(object):

    def __init__(self):
        self._gmt_create = None
        self._gmt_modified = None
        self._operate_info = None
        self._operate_time = None
        self._operator_code = None
        self._operator_name = None
        self._order_code = None
        self._order_id = None
        self._order_type = None
        self._process_status = None
        self._remark = None

    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def operate_info(self):
        return self._operate_info

    @operate_info.setter
    def operate_info(self, value):
        self._operate_info = value
    @property
    def operate_time(self):
        return self._operate_time

    @operate_time.setter
    def operate_time(self, value):
        self._operate_time = value
    @property
    def operator_code(self):
        return self._operator_code

    @operator_code.setter
    def operator_code(self, value):
        self._operator_code = value
    @property
    def operator_name(self):
        return self._operator_name

    @operator_name.setter
    def operator_name(self, value):
        self._operator_name = value
    @property
    def order_code(self):
        return self._order_code

    @order_code.setter
    def order_code(self, value):
        self._order_code = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def order_type(self):
        return self._order_type

    @order_type.setter
    def order_type(self, value):
        self._order_type = value
    @property
    def process_status(self):
        return self._process_status

    @process_status.setter
    def process_status(self, value):
        self._process_status = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value


    def to_alipay_dict(self):
        params = dict()
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.operate_info:
            if hasattr(self.operate_info, 'to_alipay_dict'):
                params['operate_info'] = self.operate_info.to_alipay_dict()
            else:
                params['operate_info'] = self.operate_info
        if self.operate_time:
            if hasattr(self.operate_time, 'to_alipay_dict'):
                params['operate_time'] = self.operate_time.to_alipay_dict()
            else:
                params['operate_time'] = self.operate_time
        if self.operator_code:
            if hasattr(self.operator_code, 'to_alipay_dict'):
                params['operator_code'] = self.operator_code.to_alipay_dict()
            else:
                params['operator_code'] = self.operator_code
        if self.operator_name:
            if hasattr(self.operator_name, 'to_alipay_dict'):
                params['operator_name'] = self.operator_name.to_alipay_dict()
            else:
                params['operator_name'] = self.operator_name
        if self.order_code:
            if hasattr(self.order_code, 'to_alipay_dict'):
                params['order_code'] = self.order_code.to_alipay_dict()
            else:
                params['order_code'] = self.order_code
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.order_type:
            if hasattr(self.order_type, 'to_alipay_dict'):
                params['order_type'] = self.order_type.to_alipay_dict()
            else:
                params['order_type'] = self.order_type
        if self.process_status:
            if hasattr(self.process_status, 'to_alipay_dict'):
                params['process_status'] = self.process_status.to_alipay_dict()
            else:
                params['process_status'] = self.process_status
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DeliveryOrderProcessVO()
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'operate_info' in d:
            o.operate_info = d['operate_info']
        if 'operate_time' in d:
            o.operate_time = d['operate_time']
        if 'operator_code' in d:
            o.operator_code = d['operator_code']
        if 'operator_name' in d:
            o.operator_name = d['operator_name']
        if 'order_code' in d:
            o.order_code = d['order_code']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'order_type' in d:
            o.order_type = d['order_type']
        if 'process_status' in d:
            o.process_status = d['process_status']
        if 'remark' in d:
            o.remark = d['remark']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.Environmental import Environmental


class EnvironmentInfo(object):

    def __init__(self):
        self._environmental_list = None
        self._goods_id = None

    @property
    def environmental_list(self):
        return self._environmental_list

    @environmental_list.setter
    def environmental_list(self, value):
        if isinstance(value, list):
            self._environmental_list = list()
            for i in value:
                if isinstance(i, Environmental):
                    self._environmental_list.append(i)
                else:
                    self._environmental_list.append(Environmental.from_alipay_dict(i))
    @property
    def goods_id(self):
        return self._goods_id

    @goods_id.setter
    def goods_id(self, value):
        self._goods_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.environmental_list:
            if isinstance(self.environmental_list, list):
                for i in range(0, len(self.environmental_list)):
                    element = self.environmental_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.environmental_list[i] = element.to_alipay_dict()
            if hasattr(self.environmental_list, 'to_alipay_dict'):
                params['environmental_list'] = self.environmental_list.to_alipay_dict()
            else:
                params['environmental_list'] = self.environmental_list
        if self.goods_id:
            if hasattr(self.goods_id, 'to_alipay_dict'):
                params['goods_id'] = self.goods_id.to_alipay_dict()
            else:
                params['goods_id'] = self.goods_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = EnvironmentInfo()
        if 'environmental_list' in d:
            o.environmental_list = d['environmental_list']
        if 'goods_id' in d:
            o.goods_id = d['goods_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CaSystemSignFileRequest import CaSystemSignFileRequest


class AntSignUserInfoRequest(object):

    def __init__(self):
        self._auth_signer_cert_number = None
        self._auth_signer_cert_type = None
        self._auth_signer_name = None
        self._authorized = None
        self._ca_system_sign_file_request_list = None
        self._email = None
        self._mobile = None
        self._order = None
        self._our_corp = None
        self._sign_sub_type = None
        self._sign_user_id = None
        self._sign_user_type = None
        self._signer_cert_number = None
        self._signer_cert_type = None
        self._signer_name = None

    @property
    def auth_signer_cert_number(self):
        return self._auth_signer_cert_number

    @auth_signer_cert_number.setter
    def auth_signer_cert_number(self, value):
        self._auth_signer_cert_number = value
    @property
    def auth_signer_cert_type(self):
        return self._auth_signer_cert_type

    @auth_signer_cert_type.setter
    def auth_signer_cert_type(self, value):
        self._auth_signer_cert_type = value
    @property
    def auth_signer_name(self):
        return self._auth_signer_name

    @auth_signer_name.setter
    def auth_signer_name(self, value):
        self._auth_signer_name = value
    @property
    def authorized(self):
        return self._authorized

    @authorized.setter
    def authorized(self, value):
        self._authorized = value
    @property
    def ca_system_sign_file_request_list(self):
        return self._ca_system_sign_file_request_list

    @ca_system_sign_file_request_list.setter
    def ca_system_sign_file_request_list(self, value):
        if isinstance(value, list):
            self._ca_system_sign_file_request_list = list()
            for i in value:
                if isinstance(i, CaSystemSignFileRequest):
                    self._ca_system_sign_file_request_list.append(i)
                else:
                    self._ca_system_sign_file_request_list.append(CaSystemSignFileRequest.from_alipay_dict(i))
    @property
    def email(self):
        return self._email

    @email.setter
    def email(self, value):
        self._email = value
    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def order(self):
        return self._order

    @order.setter
    def order(self, value):
        self._order = value
    @property
    def our_corp(self):
        return self._our_corp

    @our_corp.setter
    def our_corp(self, value):
        self._our_corp = value
    @property
    def sign_sub_type(self):
        return self._sign_sub_type

    @sign_sub_type.setter
    def sign_sub_type(self, value):
        self._sign_sub_type = value
    @property
    def sign_user_id(self):
        return self._sign_user_id

    @sign_user_id.setter
    def sign_user_id(self, value):
        self._sign_user_id = value
    @property
    def sign_user_type(self):
        return self._sign_user_type

    @sign_user_type.setter
    def sign_user_type(self, value):
        self._sign_user_type = value
    @property
    def signer_cert_number(self):
        return self._signer_cert_number

    @signer_cert_number.setter
    def signer_cert_number(self, value):
        self._signer_cert_number = value
    @property
    def signer_cert_type(self):
        return self._signer_cert_type

    @signer_cert_type.setter
    def signer_cert_type(self, value):
        self._signer_cert_type = value
    @property
    def signer_name(self):
        return self._signer_name

    @signer_name.setter
    def signer_name(self, value):
        self._signer_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.auth_signer_cert_number:
            if hasattr(self.auth_signer_cert_number, 'to_alipay_dict'):
                params['auth_signer_cert_number'] = self.auth_signer_cert_number.to_alipay_dict()
            else:
                params['auth_signer_cert_number'] = self.auth_signer_cert_number
        if self.auth_signer_cert_type:
            if hasattr(self.auth_signer_cert_type, 'to_alipay_dict'):
                params['auth_signer_cert_type'] = self.auth_signer_cert_type.to_alipay_dict()
            else:
                params['auth_signer_cert_type'] = self.auth_signer_cert_type
        if self.auth_signer_name:
            if hasattr(self.auth_signer_name, 'to_alipay_dict'):
                params['auth_signer_name'] = self.auth_signer_name.to_alipay_dict()
            else:
                params['auth_signer_name'] = self.auth_signer_name
        if self.authorized:
            if hasattr(self.authorized, 'to_alipay_dict'):
                params['authorized'] = self.authorized.to_alipay_dict()
            else:
                params['authorized'] = self.authorized
        if self.ca_system_sign_file_request_list:
            if isinstance(self.ca_system_sign_file_request_list, list):
                for i in range(0, len(self.ca_system_sign_file_request_list)):
                    element = self.ca_system_sign_file_request_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ca_system_sign_file_request_list[i] = element.to_alipay_dict()
            if hasattr(self.ca_system_sign_file_request_list, 'to_alipay_dict'):
                params['ca_system_sign_file_request_list'] = self.ca_system_sign_file_request_list.to_alipay_dict()
            else:
                params['ca_system_sign_file_request_list'] = self.ca_system_sign_file_request_list
        if self.email:
            if hasattr(self.email, 'to_alipay_dict'):
                params['email'] = self.email.to_alipay_dict()
            else:
                params['email'] = self.email
        if self.mobile:
            if hasattr(self.mobile, 'to_alipay_dict'):
                params['mobile'] = self.mobile.to_alipay_dict()
            else:
                params['mobile'] = self.mobile
        if self.order:
            if hasattr(self.order, 'to_alipay_dict'):
                params['order'] = self.order.to_alipay_dict()
            else:
                params['order'] = self.order
        if self.our_corp:
            if hasattr(self.our_corp, 'to_alipay_dict'):
                params['our_corp'] = self.our_corp.to_alipay_dict()
            else:
                params['our_corp'] = self.our_corp
        if self.sign_sub_type:
            if hasattr(self.sign_sub_type, 'to_alipay_dict'):
                params['sign_sub_type'] = self.sign_sub_type.to_alipay_dict()
            else:
                params['sign_sub_type'] = self.sign_sub_type
        if self.sign_user_id:
            if hasattr(self.sign_user_id, 'to_alipay_dict'):
                params['sign_user_id'] = self.sign_user_id.to_alipay_dict()
            else:
                params['sign_user_id'] = self.sign_user_id
        if self.sign_user_type:
            if hasattr(self.sign_user_type, 'to_alipay_dict'):
                params['sign_user_type'] = self.sign_user_type.to_alipay_dict()
            else:
                params['sign_user_type'] = self.sign_user_type
        if self.signer_cert_number:
            if hasattr(self.signer_cert_number, 'to_alipay_dict'):
                params['signer_cert_number'] = self.signer_cert_number.to_alipay_dict()
            else:
                params['signer_cert_number'] = self.signer_cert_number
        if self.signer_cert_type:
            if hasattr(self.signer_cert_type, 'to_alipay_dict'):
                params['signer_cert_type'] = self.signer_cert_type.to_alipay_dict()
            else:
                params['signer_cert_type'] = self.signer_cert_type
        if self.signer_name:
            if hasattr(self.signer_name, 'to_alipay_dict'):
                params['signer_name'] = self.signer_name.to_alipay_dict()
            else:
                params['signer_name'] = self.signer_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntSignUserInfoRequest()
        if 'auth_signer_cert_number' in d:
            o.auth_signer_cert_number = d['auth_signer_cert_number']
        if 'auth_signer_cert_type' in d:
            o.auth_signer_cert_type = d['auth_signer_cert_type']
        if 'auth_signer_name' in d:
            o.auth_signer_name = d['auth_signer_name']
        if 'authorized' in d:
            o.authorized = d['authorized']
        if 'ca_system_sign_file_request_list' in d:
            o.ca_system_sign_file_request_list = d['ca_system_sign_file_request_list']
        if 'email' in d:
            o.email = d['email']
        if 'mobile' in d:
            o.mobile = d['mobile']
        if 'order' in d:
            o.order = d['order']
        if 'our_corp' in d:
            o.our_corp = d['our_corp']
        if 'sign_sub_type' in d:
            o.sign_sub_type = d['sign_sub_type']
        if 'sign_user_id' in d:
            o.sign_user_id = d['sign_user_id']
        if 'sign_user_type' in d:
            o.sign_user_type = d['sign_user_type']
        if 'signer_cert_number' in d:
            o.signer_cert_number = d['signer_cert_number']
        if 'signer_cert_type' in d:
            o.signer_cert_type = d['signer_cert_type']
        if 'signer_name' in d:
            o.signer_name = d['signer_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundCouponOrderRefundModel(object):

    def __init__(self):
        self._amount = None
        self._auth_no = None
        self._out_request_no = None
        self._remark = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def auth_no(self):
        return self._auth_no

    @auth_no.setter
    def auth_no(self, value):
        self._auth_no = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.auth_no:
            if hasattr(self.auth_no, 'to_alipay_dict'):
                params['auth_no'] = self.auth_no.to_alipay_dict()
            else:
                params['auth_no'] = self.auth_no
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundCouponOrderRefundModel()
        if 'amount' in d:
            o.amount = d['amount']
        if 'auth_no' in d:
            o.auth_no = d['auth_no']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'remark' in d:
            o.remark = d['remark']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ReferenceId import ReferenceId
from alipay.aop.api.domain.PaymentGoods import PaymentGoods
from alipay.aop.api.domain.ReferenceId import ReferenceId
from alipay.aop.api.domain.Shipping import Shipping


class AcquireOrder(object):

    def __init__(self):
        self._buyer_out_member_id = None
        self._goods = None
        self._order_amount = None
        self._order_create_time = None
        self._order_currency = None
        self._order_expiry_time = None
        self._out_order_id = None
        self._remark = None
        self._seller_out_member_id = None
        self._shipping = None

    @property
    def buyer_out_member_id(self):
        return self._buyer_out_member_id

    @buyer_out_member_id.setter
    def buyer_out_member_id(self, value):
        if isinstance(value, ReferenceId):
            self._buyer_out_member_id = value
        else:
            self._buyer_out_member_id = ReferenceId.from_alipay_dict(value)
    @property
    def goods(self):
        return self._goods

    @goods.setter
    def goods(self, value):
        if isinstance(value, list):
            self._goods = list()
            for i in value:
                if isinstance(i, PaymentGoods):
                    self._goods.append(i)
                else:
                    self._goods.append(PaymentGoods.from_alipay_dict(i))
    @property
    def order_amount(self):
        return self._order_amount

    @order_amount.setter
    def order_amount(self, value):
        self._order_amount = value
    @property
    def order_create_time(self):
        return self._order_create_time

    @order_create_time.setter
    def order_create_time(self, value):
        self._order_create_time = value
    @property
    def order_currency(self):
        return self._order_currency

    @order_currency.setter
    def order_currency(self, value):
        self._order_currency = value
    @property
    def order_expiry_time(self):
        return self._order_expiry_time

    @order_expiry_time.setter
    def order_expiry_time(self, value):
        self._order_expiry_time = value
    @property
    def out_order_id(self):
        return self._out_order_id

    @out_order_id.setter
    def out_order_id(self, value):
        self._out_order_id = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value
    @property
    def seller_out_member_id(self):
        return self._seller_out_member_id

    @seller_out_member_id.setter
    def seller_out_member_id(self, value):
        if isinstance(value, ReferenceId):
            self._seller_out_member_id = value
        else:
            self._seller_out_member_id = ReferenceId.from_alipay_dict(value)
    @property
    def shipping(self):
        return self._shipping

    @shipping.setter
    def shipping(self, value):
        if isinstance(value, Shipping):
            self._shipping = value
        else:
            self._shipping = Shipping.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.buyer_out_member_id:
            if hasattr(self.buyer_out_member_id, 'to_alipay_dict'):
                params['buyer_out_member_id'] = self.buyer_out_member_id.to_alipay_dict()
            else:
                params['buyer_out_member_id'] = self.buyer_out_member_id
        if self.goods:
            if isinstance(self.goods, list):
                for i in range(0, len(self.goods)):
                    element = self.goods[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.goods[i] = element.to_alipay_dict()
            if hasattr(self.goods, 'to_alipay_dict'):
                params['goods'] = self.goods.to_alipay_dict()
            else:
                params['goods'] = self.goods
        if self.order_amount:
            if hasattr(self.order_amount, 'to_alipay_dict'):
                params['order_amount'] = self.order_amount.to_alipay_dict()
            else:
                params['order_amount'] = self.order_amount
        if self.order_create_time:
            if hasattr(self.order_create_time, 'to_alipay_dict'):
                params['order_create_time'] = self.order_create_time.to_alipay_dict()
            else:
                params['order_create_time'] = self.order_create_time
        if self.order_currency:
            if hasattr(self.order_currency, 'to_alipay_dict'):
                params['order_currency'] = self.order_currency.to_alipay_dict()
            else:
                params['order_currency'] = self.order_currency
        if self.order_expiry_time:
            if hasattr(self.order_expiry_time, 'to_alipay_dict'):
                params['order_expiry_time'] = self.order_expiry_time.to_alipay_dict()
            else:
                params['order_expiry_time'] = self.order_expiry_time
        if self.out_order_id:
            if hasattr(self.out_order_id, 'to_alipay_dict'):
                params['out_order_id'] = self.out_order_id.to_alipay_dict()
            else:
                params['out_order_id'] = self.out_order_id
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        if self.seller_out_member_id:
            if hasattr(self.seller_out_member_id, 'to_alipay_dict'):
                params['seller_out_member_id'] = self.seller_out_member_id.to_alipay_dict()
            else:
                params['seller_out_member_id'] = self.seller_out_member_id
        if self.shipping:
            if hasattr(self.shipping, 'to_alipay_dict'):
                params['shipping'] = self.shipping.to_alipay_dict()
            else:
                params['shipping'] = self.shipping
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AcquireOrder()
        if 'buyer_out_member_id' in d:
            o.buyer_out_member_id = d['buyer_out_member_id']
        if 'goods' in d:
            o.goods = d['goods']
        if 'order_amount' in d:
            o.order_amount = d['order_amount']
        if 'order_create_time' in d:
            o.order_create_time = d['order_create_time']
        if 'order_currency' in d:
            o.order_currency = d['order_currency']
        if 'order_expiry_time' in d:
            o.order_expiry_time = d['order_expiry_time']
        if 'out_order_id' in d:
            o.out_order_id = d['out_order_id']
        if 'remark' in d:
            o.remark = d['remark']
        if 'seller_out_member_id' in d:
            o.seller_out_member_id = d['seller_out_member_id']
        if 'shipping' in d:
            o.shipping = d['shipping']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoMycarCarmodelBatchqueryModel(object):

    def __init__(self):
        self._brand_id = None
        self._company_id = None
        self._query_type = None
        self._serie_id = None

    @property
    def brand_id(self):
        return self._brand_id

    @brand_id.setter
    def brand_id(self, value):
        self._brand_id = value
    @property
    def company_id(self):
        return self._company_id

    @company_id.setter
    def company_id(self, value):
        self._company_id = value
    @property
    def query_type(self):
        return self._query_type

    @query_type.setter
    def query_type(self, value):
        self._query_type = value
    @property
    def serie_id(self):
        return self._serie_id

    @serie_id.setter
    def serie_id(self, value):
        self._serie_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.brand_id:
            if hasattr(self.brand_id, 'to_alipay_dict'):
                params['brand_id'] = self.brand_id.to_alipay_dict()
            else:
                params['brand_id'] = self.brand_id
        if self.company_id:
            if hasattr(self.company_id, 'to_alipay_dict'):
                params['company_id'] = self.company_id.to_alipay_dict()
            else:
                params['company_id'] = self.company_id
        if self.query_type:
            if hasattr(self.query_type, 'to_alipay_dict'):
                params['query_type'] = self.query_type.to_alipay_dict()
            else:
                params['query_type'] = self.query_type
        if self.serie_id:
            if hasattr(self.serie_id, 'to_alipay_dict'):
                params['serie_id'] = self.serie_id.to_alipay_dict()
            else:
                params['serie_id'] = self.serie_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoMycarCarmodelBatchqueryModel()
        if 'brand_id' in d:
            o.brand_id = d['brand_id']
        if 'company_id' in d:
            o.company_id = d['company_id']
        if 'query_type' in d:
            o.query_type = d['query_type']
        if 'serie_id' in d:
            o.serie_id = d['serie_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenMiniAmpeQrcodeCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniAmpeQrcodeCreateResponse, self).__init__()
        self._qrcode_img_url = None

    @property
    def qrcode_img_url(self):
        return self._qrcode_img_url

    @qrcode_img_url.setter
    def qrcode_img_url(self, value):
        self._qrcode_img_url = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniAmpeQrcodeCreateResponse, self).parse_response_content(response_content)
        if 'qrcode_img_url' in response:
            self.qrcode_img_url = response['qrcode_img_url']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankCreditLoanapplyFinleaseSignQueryResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditLoanapplyFinleaseSignQueryResponse, self).__init__()
        self._msg_content = None

    @property
    def msg_content(self):
        return self._msg_content

    @msg_content.setter
    def msg_content(self, value):
        self._msg_content = value

    def parse_response_content(self, response_content):
        response = super(MybankCreditLoanapplyFinleaseSignQueryResponse, self).parse_response_content(response_content)
        if 'msg_content' in response:
            self.msg_content = response['msg_content']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ViolationEvent(object):

    def __init__(self):
        self._can_appeal = None
        self._can_rectify = None
        self._punish_action = None
        self._status = None
        self._target_id = None
        self._target_name = None
        self._target_type = None
        self._violation_record_id = None
        self._violation_time = None
        self._violation_type = None

    @property
    def can_appeal(self):
        return self._can_appeal

    @can_appeal.setter
    def can_appeal(self, value):
        self._can_appeal = value
    @property
    def can_rectify(self):
        return self._can_rectify

    @can_rectify.setter
    def can_rectify(self, value):
        self._can_rectify = value
    @property
    def punish_action(self):
        return self._punish_action

    @punish_action.setter
    def punish_action(self, value):
        self._punish_action = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def target_id(self):
        return self._target_id

    @target_id.setter
    def target_id(self, value):
        self._target_id = value
    @property
    def target_name(self):
        return self._target_name

    @target_name.setter
    def target_name(self, value):
        self._target_name = value
    @property
    def target_type(self):
        return self._target_type

    @target_type.setter
    def target_type(self, value):
        self._target_type = value
    @property
    def violation_record_id(self):
        return self._violation_record_id

    @violation_record_id.setter
    def violation_record_id(self, value):
        self._violation_record_id = value
    @property
    def violation_time(self):
        return self._violation_time

    @violation_time.setter
    def violation_time(self, value):
        self._violation_time = value
    @property
    def violation_type(self):
        return self._violation_type

    @violation_type.setter
    def violation_type(self, value):
        self._violation_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.can_appeal:
            if hasattr(self.can_appeal, 'to_alipay_dict'):
                params['can_appeal'] = self.can_appeal.to_alipay_dict()
            else:
                params['can_appeal'] = self.can_appeal
        if self.can_rectify:
            if hasattr(self.can_rectify, 'to_alipay_dict'):
                params['can_rectify'] = self.can_rectify.to_alipay_dict()
            else:
                params['can_rectify'] = self.can_rectify
        if self.punish_action:
            if hasattr(self.punish_action, 'to_alipay_dict'):
                params['punish_action'] = self.punish_action.to_alipay_dict()
            else:
                params['punish_action'] = self.punish_action
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.target_id:
            if hasattr(self.target_id, 'to_alipay_dict'):
                params['target_id'] = self.target_id.to_alipay_dict()
            else:
                params['target_id'] = self.target_id
        if self.target_name:
            if hasattr(self.target_name, 'to_alipay_dict'):
                params['target_name'] = self.target_name.to_alipay_dict()
            else:
                params['target_name'] = self.target_name
        if self.target_type:
            if hasattr(self.target_type, 'to_alipay_dict'):
                params['target_type'] = self.target_type.to_alipay_dict()
            else:
                params['target_type'] = self.target_type
        if self.violation_record_id:
            if hasattr(self.violation_record_id, 'to_alipay_dict'):
                params['violation_record_id'] = self.violation_record_id.to_alipay_dict()
            else:
                params['violation_record_id'] = self.violation_record_id
        if self.violation_time:
            if hasattr(self.violation_time, 'to_alipay_dict'):
                params['violation_time'] = self.violation_time.to_alipay_dict()
            else:
                params['violation_time'] = self.violation_time
        if self.violation_type:
            if hasattr(self.violation_type, 'to_alipay_dict'):
                params['violation_type'] = self.violation_type.to_alipay_dict()
            else:
                params['violation_type'] = self.violation_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ViolationEvent()
        if 'can_appeal' in d:
            o.can_appeal = d['can_appeal']
        if 'can_rectify' in d:
            o.can_rectify = d['can_rectify']
        if 'punish_action' in d:
            o.punish_action = d['punish_action']
        if 'status' in d:
            o.status = d['status']
        if 'target_id' in d:
            o.target_id = d['target_id']
        if 'target_name' in d:
            o.target_name = d['target_name']
        if 'target_type' in d:
            o.target_type = d['target_type']
        if 'violation_record_id' in d:
            o.violation_record_id = d['violation_record_id']
        if 'violation_time' in d:
            o.violation_time = d['violation_time']
        if 'violation_type' in d:
            o.violation_type = d['violation_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ContractInfoVO import ContractInfoVO


class ContractBatchInfoOpenApiResult(object):

    def __init__(self):
        self._approval_status = None
        self._contract_infos = None

    @property
    def approval_status(self):
        return self._approval_status

    @approval_status.setter
    def approval_status(self, value):
        self._approval_status = value
    @property
    def contract_infos(self):
        return self._contract_infos

    @contract_infos.setter
    def contract_infos(self, value):
        if isinstance(value, list):
            self._contract_infos = list()
            for i in value:
                if isinstance(i, ContractInfoVO):
                    self._contract_infos.append(i)
                else:
                    self._contract_infos.append(ContractInfoVO.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.approval_status:
            if hasattr(self.approval_status, 'to_alipay_dict'):
                params['approval_status'] = self.approval_status.to_alipay_dict()
            else:
                params['approval_status'] = self.approval_status
        if self.contract_infos:
            if isinstance(self.contract_infos, list):
                for i in range(0, len(self.contract_infos)):
                    element = self.contract_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.contract_infos[i] = element.to_alipay_dict()
            if hasattr(self.contract_infos, 'to_alipay_dict'):
                params['contract_infos'] = self.contract_infos.to_alipay_dict()
            else:
                params['contract_infos'] = self.contract_infos
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ContractBatchInfoOpenApiResult()
        if 'approval_status' in d:
            o.approval_status = d['approval_status']
        if 'contract_infos' in d:
            o.contract_infos = d['contract_infos']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.RecruitEnrollInfo import RecruitEnrollInfo


class AlipayMarketingRecruitEnrollCreateModel(object):

    def __init__(self):
        self._enroll_info = None
        self._enroll_scene_type = None
        self._out_biz_no = None
        self._plan_id = None

    @property
    def enroll_info(self):
        return self._enroll_info

    @enroll_info.setter
    def enroll_info(self, value):
        if isinstance(value, RecruitEnrollInfo):
            self._enroll_info = value
        else:
            self._enroll_info = RecruitEnrollInfo.from_alipay_dict(value)
    @property
    def enroll_scene_type(self):
        return self._enroll_scene_type

    @enroll_scene_type.setter
    def enroll_scene_type(self, value):
        self._enroll_scene_type = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def plan_id(self):
        return self._plan_id

    @plan_id.setter
    def plan_id(self, value):
        self._plan_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.enroll_info:
            if hasattr(self.enroll_info, 'to_alipay_dict'):
                params['enroll_info'] = self.enroll_info.to_alipay_dict()
            else:
                params['enroll_info'] = self.enroll_info
        if self.enroll_scene_type:
            if hasattr(self.enroll_scene_type, 'to_alipay_dict'):
                params['enroll_scene_type'] = self.enroll_scene_type.to_alipay_dict()
            else:
                params['enroll_scene_type'] = self.enroll_scene_type
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.plan_id:
            if hasattr(self.plan_id, 'to_alipay_dict'):
                params['plan_id'] = self.plan_id.to_alipay_dict()
            else:
                params['plan_id'] = self.plan_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingRecruitEnrollCreateModel()
        if 'enroll_info' in d:
            o.enroll_info = d['enroll_info']
        if 'enroll_scene_type' in d:
            o.enroll_scene_type = d['enroll_scene_type']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'plan_id' in d:
            o.plan_id = d['plan_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ExperimentInfo import ExperimentInfo


class AlipayDigitalopUcdpApeexperimentQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDigitalopUcdpApeexperimentQueryResponse, self).__init__()
        self._experiment_info_list = None
        self._running_experiment_id = None

    @property
    def experiment_info_list(self):
        return self._experiment_info_list

    @experiment_info_list.setter
    def experiment_info_list(self, value):
        if isinstance(value, list):
            self._experiment_info_list = list()
            for i in value:
                if isinstance(i, ExperimentInfo):
                    self._experiment_info_list.append(i)
                else:
                    self._experiment_info_list.append(ExperimentInfo.from_alipay_dict(i))
    @property
    def running_experiment_id(self):
        return self._running_experiment_id

    @running_experiment_id.setter
    def running_experiment_id(self, value):
        self._running_experiment_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayDigitalopUcdpApeexperimentQueryResponse, self).parse_response_content(response_content)
        if 'experiment_info_list' in response:
            self.experiment_info_list = response['experiment_info_list']
        if 'running_experiment_id' in response:
            self.running_experiment_id = response['running_experiment_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class EnterpriseCustomerInfoVO(object):

    def __init__(self):
        self._cert_name = None
        self._enterprise_addr = None
        self._enterprise_bank_card_name = None
        self._enterprise_bank_name = None
        self._enterprise_bank_no = None
        self._enterprise_phone = None
        self._legal_cert_no = None
        self._legal_mobile_phone = None
        self._legal_name = None
        self._unified_social_cert_code = None

    @property
    def cert_name(self):
        return self._cert_name

    @cert_name.setter
    def cert_name(self, value):
        self._cert_name = value
    @property
    def enterprise_addr(self):
        return self._enterprise_addr

    @enterprise_addr.setter
    def enterprise_addr(self, value):
        self._enterprise_addr = value
    @property
    def enterprise_bank_card_name(self):
        return self._enterprise_bank_card_name

    @enterprise_bank_card_name.setter
    def enterprise_bank_card_name(self, value):
        self._enterprise_bank_card_name = value
    @property
    def enterprise_bank_name(self):
        return self._enterprise_bank_name

    @enterprise_bank_name.setter
    def enterprise_bank_name(self, value):
        self._enterprise_bank_name = value
    @property
    def enterprise_bank_no(self):
        return self._enterprise_bank_no

    @enterprise_bank_no.setter
    def enterprise_bank_no(self, value):
        self._enterprise_bank_no = value
    @property
    def enterprise_phone(self):
        return self._enterprise_phone

    @enterprise_phone.setter
    def enterprise_phone(self, value):
        self._enterprise_phone = value
    @property
    def legal_cert_no(self):
        return self._legal_cert_no

    @legal_cert_no.setter
    def legal_cert_no(self, value):
        self._legal_cert_no = value
    @property
    def legal_mobile_phone(self):
        return self._legal_mobile_phone

    @legal_mobile_phone.setter
    def legal_mobile_phone(self, value):
        self._legal_mobile_phone = value
    @property
    def legal_name(self):
        return self._legal_name

    @legal_name.setter
    def legal_name(self, value):
        self._legal_name = value
    @property
    def unified_social_cert_code(self):
        return self._unified_social_cert_code

    @unified_social_cert_code.setter
    def unified_social_cert_code(self, value):
        self._unified_social_cert_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.cert_name:
            if hasattr(self.cert_name, 'to_alipay_dict'):
                params['cert_name'] = self.cert_name.to_alipay_dict()
            else:
                params['cert_name'] = self.cert_name
        if self.enterprise_addr:
            if hasattr(self.enterprise_addr, 'to_alipay_dict'):
                params['enterprise_addr'] = self.enterprise_addr.to_alipay_dict()
            else:
                params['enterprise_addr'] = self.enterprise_addr
        if self.enterprise_bank_card_name:
            if hasattr(self.enterprise_bank_card_name, 'to_alipay_dict'):
                params['enterprise_bank_card_name'] = self.enterprise_bank_card_name.to_alipay_dict()
            else:
                params['enterprise_bank_card_name'] = self.enterprise_bank_card_name
        if self.enterprise_bank_name:
            if hasattr(self.enterprise_bank_name, 'to_alipay_dict'):
                params['enterprise_bank_name'] = self.enterprise_bank_name.to_alipay_dict()
            else:
                params['enterprise_bank_name'] = self.enterprise_bank_name
        if self.enterprise_bank_no:
            if hasattr(self.enterprise_bank_no, 'to_alipay_dict'):
                params['enterprise_bank_no'] = self.enterprise_bank_no.to_alipay_dict()
            else:
                params['enterprise_bank_no'] = self.enterprise_bank_no
        if self.enterprise_phone:
            if hasattr(self.enterprise_phone, 'to_alipay_dict'):
                params['enterprise_phone'] = self.enterprise_phone.to_alipay_dict()
            else:
                params['enterprise_phone'] = self.enterprise_phone
        if self.legal_cert_no:
            if hasattr(self.legal_cert_no, 'to_alipay_dict'):
                params['legal_cert_no'] = self.legal_cert_no.to_alipay_dict()
            else:
                params['legal_cert_no'] = self.legal_cert_no
        if self.legal_mobile_phone:
            if hasattr(self.legal_mobile_phone, 'to_alipay_dict'):
                params['legal_mobile_phone'] = self.legal_mobile_phone.to_alipay_dict()
            else:
                params['legal_mobile_phone'] = self.legal_mobile_phone
        if self.legal_name:
            if hasattr(self.legal_name, 'to_alipay_dict'):
                params['legal_name'] = self.legal_name.to_alipay_dict()
            else:
                params['legal_name'] = self.legal_name
        if self.unified_social_cert_code:
            if hasattr(self.unified_social_cert_code, 'to_alipay_dict'):
                params['unified_social_cert_code'] = self.unified_social_cert_code.to_alipay_dict()
            else:
                params['unified_social_cert_code'] = self.unified_social_cert_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = EnterpriseCustomerInfoVO()
        if 'cert_name' in d:
            o.cert_name = d['cert_name']
        if 'enterprise_addr' in d:
            o.enterprise_addr = d['enterprise_addr']
        if 'enterprise_bank_card_name' in d:
            o.enterprise_bank_card_name = d['enterprise_bank_card_name']
        if 'enterprise_bank_name' in d:
            o.enterprise_bank_name = d['enterprise_bank_name']
        if 'enterprise_bank_no' in d:
            o.enterprise_bank_no = d['enterprise_bank_no']
        if 'enterprise_phone' in d:
            o.enterprise_phone = d['enterprise_phone']
        if 'legal_cert_no' in d:
            o.legal_cert_no = d['legal_cert_no']
        if 'legal_mobile_phone' in d:
            o.legal_mobile_phone = d['legal_mobile_phone']
        if 'legal_name' in d:
            o.legal_name = d['legal_name']
        if 'unified_social_cert_code' in d:
            o.unified_social_cert_code = d['unified_social_cert_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CfbudmacPurchaseApplyInfoDTO(object):

    def __init__(self):
        self._begin_cycle = None
        self._biz_budget_apply_code = None
        self._biz_budget_id = None
        self._biz_type = None
        self._budget_strategy = None
        self._currency = None
        self._end_cycle = None
        self._gmt_create = None
        self._gmt_modified = None
        self._id = None
        self._pool_code = None
        self._remain_amount = None
        self._status = None

    @property
    def begin_cycle(self):
        return self._begin_cycle

    @begin_cycle.setter
    def begin_cycle(self, value):
        self._begin_cycle = value
    @property
    def biz_budget_apply_code(self):
        return self._biz_budget_apply_code

    @biz_budget_apply_code.setter
    def biz_budget_apply_code(self, value):
        self._biz_budget_apply_code = value
    @property
    def biz_budget_id(self):
        return self._biz_budget_id

    @biz_budget_id.setter
    def biz_budget_id(self, value):
        self._biz_budget_id = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def budget_strategy(self):
        return self._budget_strategy

    @budget_strategy.setter
    def budget_strategy(self, value):
        self._budget_strategy = value
    @property
    def currency(self):
        return self._currency

    @currency.setter
    def currency(self, value):
        self._currency = value
    @property
    def end_cycle(self):
        return self._end_cycle

    @end_cycle.setter
    def end_cycle(self, value):
        self._end_cycle = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def pool_code(self):
        return self._pool_code

    @pool_code.setter
    def pool_code(self, value):
        self._pool_code = value
    @property
    def remain_amount(self):
        return self._remain_amount

    @remain_amount.setter
    def remain_amount(self, value):
        self._remain_amount = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.begin_cycle:
            if hasattr(self.begin_cycle, 'to_alipay_dict'):
                params['begin_cycle'] = self.begin_cycle.to_alipay_dict()
            else:
                params['begin_cycle'] = self.begin_cycle
        if self.biz_budget_apply_code:
            if hasattr(self.biz_budget_apply_code, 'to_alipay_dict'):
                params['biz_budget_apply_code'] = self.biz_budget_apply_code.to_alipay_dict()
            else:
                params['biz_budget_apply_code'] = self.biz_budget_apply_code
        if self.biz_budget_id:
            if hasattr(self.biz_budget_id, 'to_alipay_dict'):
                params['biz_budget_id'] = self.biz_budget_id.to_alipay_dict()
            else:
                params['biz_budget_id'] = self.biz_budget_id
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.budget_strategy:
            if hasattr(self.budget_strategy, 'to_alipay_dict'):
                params['budget_strategy'] = self.budget_strategy.to_alipay_dict()
            else:
                params['budget_strategy'] = self.budget_strategy
        if self.currency:
            if hasattr(self.currency, 'to_alipay_dict'):
                params['currency'] = self.currency.to_alipay_dict()
            else:
                params['currency'] = self.currency
        if self.end_cycle:
            if hasattr(self.end_cycle, 'to_alipay_dict'):
                params['end_cycle'] = self.end_cycle.to_alipay_dict()
            else:
                params['end_cycle'] = self.end_cycle
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.pool_code:
            if hasattr(self.pool_code, 'to_alipay_dict'):
                params['pool_code'] = self.pool_code.to_alipay_dict()
            else:
                params['pool_code'] = self.pool_code
        if self.remain_amount:
            if hasattr(self.remain_amount, 'to_alipay_dict'):
                params['remain_amount'] = self.remain_amount.to_alipay_dict()
            else:
                params['remain_amount'] = self.remain_amount
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CfbudmacPurchaseApplyInfoDTO()
        if 'begin_cycle' in d:
            o.begin_cycle = d['begin_cycle']
        if 'biz_budget_apply_code' in d:
            o.biz_budget_apply_code = d['biz_budget_apply_code']
        if 'biz_budget_id' in d:
            o.biz_budget_id = d['biz_budget_id']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'budget_strategy' in d:
            o.budget_strategy = d['budget_strategy']
        if 'currency' in d:
            o.currency = d['currency']
        if 'end_cycle' in d:
            o.end_cycle = d['end_cycle']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'id' in d:
            o.id = d['id']
        if 'pool_code' in d:
            o.pool_code = d['pool_code']
        if 'remain_amount' in d:
            o.remain_amount = d['remain_amount']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TextDiff(object):

    def __init__(self):
        self._operation = None
        self._text = None

    @property
    def operation(self):
        return self._operation

    @operation.setter
    def operation(self, value):
        self._operation = value
    @property
    def text(self):
        return self._text

    @text.setter
    def text(self, value):
        self._text = value


    def to_alipay_dict(self):
        params = dict()
        if self.operation:
            if hasattr(self.operation, 'to_alipay_dict'):
                params['operation'] = self.operation.to_alipay_dict()
            else:
                params['operation'] = self.operation
        if self.text:
            if hasattr(self.text, 'to_alipay_dict'):
                params['text'] = self.text.to_alipay_dict()
            else:
                params['text'] = self.text
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TextDiff()
        if 'operation' in d:
            o.operation = d['operation']
        if 'text' in d:
            o.text = d['text']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.RecommendAccountDTO import RecommendAccountDTO
from alipay.aop.api.domain.RecommendAccountDTO import RecommendAccountDTO


class AlipayOpenSpOperationApplyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenSpOperationApplyResponse, self).__init__()
        self._batch_no = None
        self._bind_account = None
        self._recommend_accounts = None

    @property
    def batch_no(self):
        return self._batch_no

    @batch_no.setter
    def batch_no(self, value):
        self._batch_no = value
    @property
    def bind_account(self):
        return self._bind_account

    @bind_account.setter
    def bind_account(self, value):
        if isinstance(value, RecommendAccountDTO):
            self._bind_account = value
        else:
            self._bind_account = RecommendAccountDTO.from_alipay_dict(value)
    @property
    def recommend_accounts(self):
        return self._recommend_accounts

    @recommend_accounts.setter
    def recommend_accounts(self, value):
        if isinstance(value, list):
            self._recommend_accounts = list()
            for i in value:
                if isinstance(i, RecommendAccountDTO):
                    self._recommend_accounts.append(i)
                else:
                    self._recommend_accounts.append(RecommendAccountDTO.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOpenSpOperationApplyResponse, self).parse_response_content(response_content)
        if 'batch_no' in response:
            self.batch_no = response['batch_no']
        if 'bind_account' in response:
            self.bind_account = response['bind_account']
        if 'recommend_accounts' in response:
            self.recommend_accounts = response['recommend_accounts']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.TemplateRightsContentDTO import TemplateRightsContentDTO


class TemplateOpenCardConfDTO(object):

    def __init__(self):
        self._card_rights = None
        self._conf = None
        self._open_card_source_type = None
        self._open_card_url = None
        self._source_app_id = None

    @property
    def card_rights(self):
        return self._card_rights

    @card_rights.setter
    def card_rights(self, value):
        if isinstance(value, list):
            self._card_rights = list()
            for i in value:
                if isinstance(i, TemplateRightsContentDTO):
                    self._card_rights.append(i)
                else:
                    self._card_rights.append(TemplateRightsContentDTO.from_alipay_dict(i))
    @property
    def conf(self):
        return self._conf

    @conf.setter
    def conf(self, value):
        self._conf = value
    @property
    def open_card_source_type(self):
        return self._open_card_source_type

    @open_card_source_type.setter
    def open_card_source_type(self, value):
        self._open_card_source_type = value
    @property
    def open_card_url(self):
        return self._open_card_url

    @open_card_url.setter
    def open_card_url(self, value):
        self._open_card_url = value
    @property
    def source_app_id(self):
        return self._source_app_id

    @source_app_id.setter
    def source_app_id(self, value):
        self._source_app_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.card_rights:
            if isinstance(self.card_rights, list):
                for i in range(0, len(self.card_rights)):
                    element = self.card_rights[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.card_rights[i] = element.to_alipay_dict()
            if hasattr(self.card_rights, 'to_alipay_dict'):
                params['card_rights'] = self.card_rights.to_alipay_dict()
            else:
                params['card_rights'] = self.card_rights
        if self.conf:
            if hasattr(self.conf, 'to_alipay_dict'):
                params['conf'] = self.conf.to_alipay_dict()
            else:
                params['conf'] = self.conf
        if self.open_card_source_type:
            if hasattr(self.open_card_source_type, 'to_alipay_dict'):
                params['open_card_source_type'] = self.open_card_source_type.to_alipay_dict()
            else:
                params['open_card_source_type'] = self.open_card_source_type
        if self.open_card_url:
            if hasattr(self.open_card_url, 'to_alipay_dict'):
                params['open_card_url'] = self.open_card_url.to_alipay_dict()
            else:
                params['open_card_url'] = self.open_card_url
        if self.source_app_id:
            if hasattr(self.source_app_id, 'to_alipay_dict'):
                params['source_app_id'] = self.source_app_id.to_alipay_dict()
            else:
                params['source_app_id'] = self.source_app_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TemplateOpenCardConfDTO()
        if 'card_rights' in d:
            o.card_rights = d['card_rights']
        if 'conf' in d:
            o.conf = d['conf']
        if 'open_card_source_type' in d:
            o.open_card_source_type = d['open_card_source_type']
        if 'open_card_url' in d:
            o.open_card_url = d['open_card_url']
        if 'source_app_id' in d:
            o.source_app_id = d['source_app_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankCreditSceneprodPreadmitQueryResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditSceneprodPreadmitQueryResponse, self).__init__()
        self._pre_admit_result = None
        self._reject_code = None
        self._reject_reason = None
        self._trace_id = None

    @property
    def pre_admit_result(self):
        return self._pre_admit_result

    @pre_admit_result.setter
    def pre_admit_result(self, value):
        self._pre_admit_result = value
    @property
    def reject_code(self):
        return self._reject_code

    @reject_code.setter
    def reject_code(self, value):
        self._reject_code = value
    @property
    def reject_reason(self):
        return self._reject_reason

    @reject_reason.setter
    def reject_reason(self, value):
        self._reject_reason = value
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value

    def parse_response_content(self, response_content):
        response = super(MybankCreditSceneprodPreadmitQueryResponse, self).parse_response_content(response_content)
        if 'pre_admit_result' in response:
            self.pre_admit_result = response['pre_admit_result']
        if 'reject_code' in response:
            self.reject_code = response['reject_code']
        if 'reject_reason' in response:
            self.reject_reason = response['reject_reason']
        if 'trace_id' in response:
            self.trace_id = response['trace_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ContractManagerProcessSyncRequest import ContractManagerProcessSyncRequest


class AlipayEcoContractProcessSyncModel(object):

    def __init__(self):
        self._batch_no = None
        self._flows = None
        self._sign_platform_code = None

    @property
    def batch_no(self):
        return self._batch_no

    @batch_no.setter
    def batch_no(self, value):
        self._batch_no = value
    @property
    def flows(self):
        return self._flows

    @flows.setter
    def flows(self, value):
        if isinstance(value, list):
            self._flows = list()
            for i in value:
                if isinstance(i, ContractManagerProcessSyncRequest):
                    self._flows.append(i)
                else:
                    self._flows.append(ContractManagerProcessSyncRequest.from_alipay_dict(i))
    @property
    def sign_platform_code(self):
        return self._sign_platform_code

    @sign_platform_code.setter
    def sign_platform_code(self, value):
        self._sign_platform_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.batch_no:
            if hasattr(self.batch_no, 'to_alipay_dict'):
                params['batch_no'] = self.batch_no.to_alipay_dict()
            else:
                params['batch_no'] = self.batch_no
        if self.flows:
            if isinstance(self.flows, list):
                for i in range(0, len(self.flows)):
                    element = self.flows[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.flows[i] = element.to_alipay_dict()
            if hasattr(self.flows, 'to_alipay_dict'):
                params['flows'] = self.flows.to_alipay_dict()
            else:
                params['flows'] = self.flows
        if self.sign_platform_code:
            if hasattr(self.sign_platform_code, 'to_alipay_dict'):
                params['sign_platform_code'] = self.sign_platform_code.to_alipay_dict()
            else:
                params['sign_platform_code'] = self.sign_platform_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoContractProcessSyncModel()
        if 'batch_no' in d:
            o.batch_no = d['batch_no']
        if 'flows' in d:
            o.flows = d['flows']
        if 'sign_platform_code' in d:
            o.sign_platform_code = d['sign_platform_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InterfaceInfoList import InterfaceInfoList


class AlipayEcoMycarParkingConfigSetModel(object):

    def __init__(self):
        self._account_no = None
        self._interface_info_list = None
        self._merchant_logo = None
        self._merchant_name = None
        self._merchant_service_phone = None

    @property
    def account_no(self):
        return self._account_no

    @account_no.setter
    def account_no(self, value):
        self._account_no = value
    @property
    def interface_info_list(self):
        return self._interface_info_list

    @interface_info_list.setter
    def interface_info_list(self, value):
        if isinstance(value, list):
            self._interface_info_list = list()
            for i in value:
                if isinstance(i, InterfaceInfoList):
                    self._interface_info_list.append(i)
                else:
                    self._interface_info_list.append(InterfaceInfoList.from_alipay_dict(i))
    @property
    def merchant_logo(self):
        return self._merchant_logo

    @merchant_logo.setter
    def merchant_logo(self, value):
        self._merchant_logo = value
    @property
    def merchant_name(self):
        return self._merchant_name

    @merchant_name.setter
    def merchant_name(self, value):
        self._merchant_name = value
    @property
    def merchant_service_phone(self):
        return self._merchant_service_phone

    @merchant_service_phone.setter
    def merchant_service_phone(self, value):
        self._merchant_service_phone = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_no:
            if hasattr(self.account_no, 'to_alipay_dict'):
                params['account_no'] = self.account_no.to_alipay_dict()
            else:
                params['account_no'] = self.account_no
        if self.interface_info_list:
            if isinstance(self.interface_info_list, list):
                for i in range(0, len(self.interface_info_list)):
                    element = self.interface_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.interface_info_list[i] = element.to_alipay_dict()
            if hasattr(self.interface_info_list, 'to_alipay_dict'):
                params['interface_info_list'] = self.interface_info_list.to_alipay_dict()
            else:
                params['interface_info_list'] = self.interface_info_list
        if self.merchant_logo:
            if hasattr(self.merchant_logo, 'to_alipay_dict'):
                params['merchant_logo'] = self.merchant_logo.to_alipay_dict()
            else:
                params['merchant_logo'] = self.merchant_logo
        if self.merchant_name:
            if hasattr(self.merchant_name, 'to_alipay_dict'):
                params['merchant_name'] = self.merchant_name.to_alipay_dict()
            else:
                params['merchant_name'] = self.merchant_name
        if self.merchant_service_phone:
            if hasattr(self.merchant_service_phone, 'to_alipay_dict'):
                params['merchant_service_phone'] = self.merchant_service_phone.to_alipay_dict()
            else:
                params['merchant_service_phone'] = self.merchant_service_phone
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoMycarParkingConfigSetModel()
        if 'account_no' in d:
            o.account_no = d['account_no']
        if 'interface_info_list' in d:
            o.interface_info_list = d['interface_info_list']
        if 'merchant_logo' in d:
            o.merchant_logo = d['merchant_logo']
        if 'merchant_name' in d:
            o.merchant_name = d['merchant_name']
        if 'merchant_service_phone' in d:
            o.merchant_service_phone = d['merchant_service_phone']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoRenthouseKaBaseinfoQueryModel(object):

    def __init__(self):
        self._ka_code = None

    @property
    def ka_code(self):
        return self._ka_code

    @ka_code.setter
    def ka_code(self, value):
        self._ka_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.ka_code:
            if hasattr(self.ka_code, 'to_alipay_dict'):
                params['ka_code'] = self.ka_code.to_alipay_dict()
            else:
                params['ka_code'] = self.ka_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoRenthouseKaBaseinfoQueryModel()
        if 'ka_code' in d:
            o.ka_code = d['ka_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.IdentityDTO import IdentityDTO
from alipay.aop.api.domain.IdentityDTO import IdentityDTO
from alipay.aop.api.domain.LocationDTO import LocationDTO


class AlipayBossProdAntlegalchainTextnotaryCreateModel(object):

    def __init__(self):
        self._app_code = None
        self._business_line_code = None
        self._business_unique_id = None
        self._content = None
        self._customer = None
        self._entity = None
        self._location = None
        self._scene_code = None
        self._submitter_name = None
        self._submitter_uid = None
        self._tenant = None
        self._token_key = None

    @property
    def app_code(self):
        return self._app_code

    @app_code.setter
    def app_code(self, value):
        self._app_code = value
    @property
    def business_line_code(self):
        return self._business_line_code

    @business_line_code.setter
    def business_line_code(self, value):
        self._business_line_code = value
    @property
    def business_unique_id(self):
        return self._business_unique_id

    @business_unique_id.setter
    def business_unique_id(self, value):
        self._business_unique_id = value
    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def customer(self):
        return self._customer

    @customer.setter
    def customer(self, value):
        if isinstance(value, IdentityDTO):
            self._customer = value
        else:
            self._customer = IdentityDTO.from_alipay_dict(value)
    @property
    def entity(self):
        return self._entity

    @entity.setter
    def entity(self, value):
        if isinstance(value, IdentityDTO):
            self._entity = value
        else:
            self._entity = IdentityDTO.from_alipay_dict(value)
    @property
    def location(self):
        return self._location

    @location.setter
    def location(self, value):
        if isinstance(value, LocationDTO):
            self._location = value
        else:
            self._location = LocationDTO.from_alipay_dict(value)
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def submitter_name(self):
        return self._submitter_name

    @submitter_name.setter
    def submitter_name(self, value):
        self._submitter_name = value
    @property
    def submitter_uid(self):
        return self._submitter_uid

    @submitter_uid.setter
    def submitter_uid(self, value):
        self._submitter_uid = value
    @property
    def tenant(self):
        return self._tenant

    @tenant.setter
    def tenant(self, value):
        self._tenant = value
    @property
    def token_key(self):
        return self._token_key

    @token_key.setter
    def token_key(self, value):
        self._token_key = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_code:
            if hasattr(self.app_code, 'to_alipay_dict'):
                params['app_code'] = self.app_code.to_alipay_dict()
            else:
                params['app_code'] = self.app_code
        if self.business_line_code:
            if hasattr(self.business_line_code, 'to_alipay_dict'):
                params['business_line_code'] = self.business_line_code.to_alipay_dict()
            else:
                params['business_line_code'] = self.business_line_code
        if self.business_unique_id:
            if hasattr(self.business_unique_id, 'to_alipay_dict'):
                params['business_unique_id'] = self.business_unique_id.to_alipay_dict()
            else:
                params['business_unique_id'] = self.business_unique_id
        if self.content:
            if hasattr(self.content, 'to_alipay_dict'):
                params['content'] = self.content.to_alipay_dict()
            else:
                params['content'] = self.content
        if self.customer:
            if hasattr(self.customer, 'to_alipay_dict'):
                params['customer'] = self.customer.to_alipay_dict()
            else:
                params['customer'] = self.customer
        if self.entity:
            if hasattr(self.entity, 'to_alipay_dict'):
                params['entity'] = self.entity.to_alipay_dict()
            else:
                params['entity'] = self.entity
        if self.location:
            if hasattr(self.location, 'to_alipay_dict'):
                params['location'] = self.location.to_alipay_dict()
            else:
                params['location'] = self.location
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.submitter_name:
            if hasattr(self.submitter_name, 'to_alipay_dict'):
                params['submitter_name'] = self.submitter_name.to_alipay_dict()
            else:
                params['submitter_name'] = self.submitter_name
        if self.submitter_uid:
            if hasattr(self.submitter_uid, 'to_alipay_dict'):
                params['submitter_uid'] = self.submitter_uid.to_alipay_dict()
            else:
                params['submitter_uid'] = self.submitter_uid
        if self.tenant:
            if hasattr(self.tenant, 'to_alipay_dict'):
                params['tenant'] = self.tenant.to_alipay_dict()
            else:
                params['tenant'] = self.tenant
        if self.token_key:
            if hasattr(self.token_key, 'to_alipay_dict'):
                params['token_key'] = self.token_key.to_alipay_dict()
            else:
                params['token_key'] = self.token_key
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossProdAntlegalchainTextnotaryCreateModel()
        if 'app_code' in d:
            o.app_code = d['app_code']
        if 'business_line_code' in d:
            o.business_line_code = d['business_line_code']
        if 'business_unique_id' in d:
            o.business_unique_id = d['business_unique_id']
        if 'content' in d:
            o.content = d['content']
        if 'customer' in d:
            o.customer = d['customer']
        if 'entity' in d:
            o.entity = d['entity']
        if 'location' in d:
            o.location = d['location']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'submitter_name' in d:
            o.submitter_name = d['submitter_name']
        if 'submitter_uid' in d:
            o.submitter_uid = d['submitter_uid']
        if 'tenant' in d:
            o.tenant = d['tenant']
        if 'token_key' in d:
            o.token_key = d['token_key']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceTransportIntelligentizeWorkscheduleCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceTransportIntelligentizeWorkscheduleCreateResponse, self).__init__()
        self._ext_info = None
        self._service_task_id = None
        self._service_task_type = None

    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def service_task_id(self):
        return self._service_task_id

    @service_task_id.setter
    def service_task_id(self, value):
        self._service_task_id = value
    @property
    def service_task_type(self):
        return self._service_task_type

    @service_task_type.setter
    def service_task_type(self, value):
        self._service_task_type = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceTransportIntelligentizeWorkscheduleCreateResponse, self).parse_response_content(response_content)
        if 'ext_info' in response:
            self.ext_info = response['ext_info']
        if 'service_task_id' in response:
            self.service_task_id = response['service_task_id']
        if 'service_task_type' in response:
            self.service_task_type = response['service_task_type']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DefiCustMemberDTO(object):

    def __init__(self):
        self._auth_status = None
        self._company_cert_no = None
        self._company_cert_type = None
        self._company_name = None
        self._id_map = None
        self._member_email = None
        self._member_id = None
        self._role_types = None
        self._status = None

    @property
    def auth_status(self):
        return self._auth_status

    @auth_status.setter
    def auth_status(self, value):
        self._auth_status = value
    @property
    def company_cert_no(self):
        return self._company_cert_no

    @company_cert_no.setter
    def company_cert_no(self, value):
        self._company_cert_no = value
    @property
    def company_cert_type(self):
        return self._company_cert_type

    @company_cert_type.setter
    def company_cert_type(self, value):
        self._company_cert_type = value
    @property
    def company_name(self):
        return self._company_name

    @company_name.setter
    def company_name(self, value):
        self._company_name = value
    @property
    def id_map(self):
        return self._id_map

    @id_map.setter
    def id_map(self, value):
        self._id_map = value
    @property
    def member_email(self):
        return self._member_email

    @member_email.setter
    def member_email(self, value):
        self._member_email = value
    @property
    def member_id(self):
        return self._member_id

    @member_id.setter
    def member_id(self, value):
        self._member_id = value
    @property
    def role_types(self):
        return self._role_types

    @role_types.setter
    def role_types(self, value):
        if isinstance(value, list):
            self._role_types = list()
            for i in value:
                self._role_types.append(i)
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.auth_status:
            if hasattr(self.auth_status, 'to_alipay_dict'):
                params['auth_status'] = self.auth_status.to_alipay_dict()
            else:
                params['auth_status'] = self.auth_status
        if self.company_cert_no:
            if hasattr(self.company_cert_no, 'to_alipay_dict'):
                params['company_cert_no'] = self.company_cert_no.to_alipay_dict()
            else:
                params['company_cert_no'] = self.company_cert_no
        if self.company_cert_type:
            if hasattr(self.company_cert_type, 'to_alipay_dict'):
                params['company_cert_type'] = self.company_cert_type.to_alipay_dict()
            else:
                params['company_cert_type'] = self.company_cert_type
        if self.company_name:
            if hasattr(self.company_name, 'to_alipay_dict'):
                params['company_name'] = self.company_name.to_alipay_dict()
            else:
                params['company_name'] = self.company_name
        if self.id_map:
            if hasattr(self.id_map, 'to_alipay_dict'):
                params['id_map'] = self.id_map.to_alipay_dict()
            else:
                params['id_map'] = self.id_map
        if self.member_email:
            if hasattr(self.member_email, 'to_alipay_dict'):
                params['member_email'] = self.member_email.to_alipay_dict()
            else:
                params['member_email'] = self.member_email
        if self.member_id:
            if hasattr(self.member_id, 'to_alipay_dict'):
                params['member_id'] = self.member_id.to_alipay_dict()
            else:
                params['member_id'] = self.member_id
        if self.role_types:
            if isinstance(self.role_types, list):
                for i in range(0, len(self.role_types)):
                    element = self.role_types[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.role_types[i] = element.to_alipay_dict()
            if hasattr(self.role_types, 'to_alipay_dict'):
                params['role_types'] = self.role_types.to_alipay_dict()
            else:
                params['role_types'] = self.role_types
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DefiCustMemberDTO()
        if 'auth_status' in d:
            o.auth_status = d['auth_status']
        if 'company_cert_no' in d:
            o.company_cert_no = d['company_cert_no']
        if 'company_cert_type' in d:
            o.company_cert_type = d['company_cert_type']
        if 'company_name' in d:
            o.company_name = d['company_name']
        if 'id_map' in d:
            o.id_map = d['id_map']
        if 'member_email' in d:
            o.member_email = d['member_email']
        if 'member_id' in d:
            o.member_id = d['member_id']
        if 'role_types' in d:
            o.role_types = d['role_types']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayInsSceneInsserviceprodSerinfoSyncModel(object):

    def __init__(self):
        self._ant_ser_prod_no = None
        self._ser_biz_no = None
        self._ser_biz_type = None
        self._service_info = None

    @property
    def ant_ser_prod_no(self):
        return self._ant_ser_prod_no

    @ant_ser_prod_no.setter
    def ant_ser_prod_no(self, value):
        self._ant_ser_prod_no = value
    @property
    def ser_biz_no(self):
        return self._ser_biz_no

    @ser_biz_no.setter
    def ser_biz_no(self, value):
        self._ser_biz_no = value
    @property
    def ser_biz_type(self):
        return self._ser_biz_type

    @ser_biz_type.setter
    def ser_biz_type(self, value):
        self._ser_biz_type = value
    @property
    def service_info(self):
        return self._service_info

    @service_info.setter
    def service_info(self, value):
        self._service_info = value


    def to_alipay_dict(self):
        params = dict()
        if self.ant_ser_prod_no:
            if hasattr(self.ant_ser_prod_no, 'to_alipay_dict'):
                params['ant_ser_prod_no'] = self.ant_ser_prod_no.to_alipay_dict()
            else:
                params['ant_ser_prod_no'] = self.ant_ser_prod_no
        if self.ser_biz_no:
            if hasattr(self.ser_biz_no, 'to_alipay_dict'):
                params['ser_biz_no'] = self.ser_biz_no.to_alipay_dict()
            else:
                params['ser_biz_no'] = self.ser_biz_no
        if self.ser_biz_type:
            if hasattr(self.ser_biz_type, 'to_alipay_dict'):
                params['ser_biz_type'] = self.ser_biz_type.to_alipay_dict()
            else:
                params['ser_biz_type'] = self.ser_biz_type
        if self.service_info:
            if hasattr(self.service_info, 'to_alipay_dict'):
                params['service_info'] = self.service_info.to_alipay_dict()
            else:
                params['service_info'] = self.service_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsSceneInsserviceprodSerinfoSyncModel()
        if 'ant_ser_prod_no' in d:
            o.ant_ser_prod_no = d['ant_ser_prod_no']
        if 'ser_biz_no' in d:
            o.ser_biz_no = d['ser_biz_no']
        if 'ser_biz_type' in d:
            o.ser_biz_type = d['ser_biz_type']
        if 'service_info' in d:
            o.service_info = d['service_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InsEndorseItem(object):

    def __init__(self):
        self._new_value = None
        self._old_value = None
        self._type = None

    @property
    def new_value(self):
        return self._new_value

    @new_value.setter
    def new_value(self, value):
        self._new_value = value
    @property
    def old_value(self):
        return self._old_value

    @old_value.setter
    def old_value(self, value):
        self._old_value = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.new_value:
            if hasattr(self.new_value, 'to_alipay_dict'):
                params['new_value'] = self.new_value.to_alipay_dict()
            else:
                params['new_value'] = self.new_value
        if self.old_value:
            if hasattr(self.old_value, 'to_alipay_dict'):
                params['old_value'] = self.old_value.to_alipay_dict()
            else:
                params['old_value'] = self.old_value
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InsEndorseItem()
        if 'new_value' in d:
            o.new_value = d['new_value']
        if 'old_value' in d:
            o.old_value = d['old_value']
        if 'type' in d:
            o.type = d['type']
        return o


